@@ -59,13 +59,11 @@ def user_cache_dir():
     - Windows: {%LOCALAPPDATA%,%APPDATA%}\glances\cache
     """
     if WINDOWS:
-        path = os.path.join(os.environ.get('LOCALAPPDATA') or os.environ.get('APPDATA'),
-                            'glances', 'cache')
+        path = os.path.join(os.environ.get('LOCALAPPDATA') or os.environ.get('APPDATA'), 'glances', 'cache')
     elif MACOS:
         path = os.path.expanduser('~/Library/Caches/glances')
     else:
-        path = os.path.join(os.environ.get('XDG_CACHE_HOME') or os.path.expanduser('~/.cache'),
-                            'glances')
+        path = os.path.join(os.environ.get('XDG_CACHE_HOME') or os.path.expanduser('~/.cache'), 'glances')
 
     return path
 
@@ -91,6 +89,24 @@ def system_config_dir():
     return path
 
 
+def default_config_dir():
+    r"""Return the system-wide config dir (full path).
+
+    - Linux, SunOS, *BSD, macOS: /usr/share/doc (as defined in the setup.py files)
+    - Windows: %APPDATA%\glances
+    """
+    if LINUX or SUNOS or BSD or MACOS:
+        path = '/usr/share/doc'
+    else:
+        path = os.environ.get('APPDATA')
+    if path is None:
+        path = ''
+    else:
+        path = os.path.join(path, 'glances')
+
+    return path
+
+
 class Config(object):
 
     """This class is used to access/read config file, if it exists.
@@ -104,7 +120,7 @@ class Config(object):
         self.config_filename = 'glances.conf'
         self._loaded_config_file = None
 
-        # Re patern for optimize research of `foo`
+        # Re pattern for optimize research of `foo`
         self.re_pattern = re.compile(r'(\`.+?\`)')
 
         try:
@@ -129,6 +145,7 @@ class Config(object):
             * /path/to/file (via -C flag)
             * user's home directory (per-user settings)
             * system-wide directory (system-wide settings)
+            * default pip directory (as defined in the setup.py file)
         """
         paths = []
 
@@ -137,13 +154,14 @@ class Config(object):
 
         paths.append(os.path.join(user_config_dir(), self.config_filename))
         paths.append(os.path.join(system_config_dir(), self.config_filename))
+        paths.append(os.path.join(default_config_dir(), self.config_filename))
 
         return paths
 
     def read(self):
         """Read the config file, if it exists. Using defaults otherwise."""
         for config_file in self.config_file_paths():
-            logger.info('Search glances.conf file in {}'.format(config_file))
+            logger.debug('Search glances.conf file in {}'.format(config_file))
             if os.path.exists(config_file):
                 try:
                     with open(config_file, encoding='utf-8') as f:
@@ -186,16 +204,26 @@ class Config(object):
         self.set_default_cwc('cpu', 'steal')
         # By default I/O wait should be lower than 1/number of CPU cores
         iowait_bottleneck = (1.0 / multiprocessing.cpu_count()) * 100.0
-        self.set_default_cwc('cpu', 'iowait',
-                             [str(iowait_bottleneck - (iowait_bottleneck * 0.20)),
-                              str(iowait_bottleneck - (iowait_bottleneck * 0.10)),
-                              str(iowait_bottleneck)])
+        self.set_default_cwc(
+            'cpu',
+            'iowait',
+            [
+                str(iowait_bottleneck - (iowait_bottleneck * 0.20)),
+                str(iowait_bottleneck - (iowait_bottleneck * 0.10)),
+                str(iowait_bottleneck),
+            ],
+        )
         # Context switches bottleneck identification #1212
         ctx_switches_bottleneck = (500000 * 0.10) * multiprocessing.cpu_count()
-        self.set_default_cwc('cpu', 'ctx_switches',
-                             [str(ctx_switches_bottleneck - (ctx_switches_bottleneck * 0.20)),
-                              str(ctx_switches_bottleneck - (ctx_switches_bottleneck * 0.10)),
-                              str(ctx_switches_bottleneck)])
+        self.set_default_cwc(
+            'cpu',
+            'ctx_switches',
+            [
+                str(ctx_switches_bottleneck - (ctx_switches_bottleneck * 0.20)),
+                str(ctx_switches_bottleneck - (ctx_switches_bottleneck * 0.10)),
+                str(ctx_switches_bottleneck),
+            ],
+        )
 
         # Per-CPU
         if not self.parser.has_section('percpu'):
@@ -268,9 +296,7 @@ class Config(object):
         """Return info about the existence of a section."""
         return self.parser.has_section(section)
 
-    def set_default_cwc(self, section,
-                        option_header=None,
-                        cwc=['50', '70', '90']):
+    def set_default_cwc(self, section, option_header=None, cwc=['50', '70', '90']):
         """Set default values for careful, warning and critical."""
         if option_header is None:
             header = ''
@@ -280,14 +306,12 @@ class Config(object):
         self.set_default(section, header + 'warning', cwc[1])
         self.set_default(section, header + 'critical', cwc[2])
 
-    def set_default(self, section, option,
-                    default):
+    def set_default(self, section, option, default):
         """If the option did not exist, create a default value."""
         if not self.parser.has_option(section, option):
             self.parser.set(section, option, default)
 
-    def get_value(self, section, option,
-                  default=None):
+    def get_value(self, section, option, default=None):
         """Get the value of an option, if it exists.
 
         If it did not exist, then return the default value.
