@@ -20,14 +20,14 @@
 """Curses interface class."""
 from __future__ import unicode_literals
 
-import re
 import sys
 
-from glances.compat import to_ascii, nativestr, b, u, itervalues
+from glances.compat import nativestr, u, itervalues, enable, disable
 from glances.globals import MACOS, WINDOWS
 from glances.logger import logger
 from glances.events import glances_events
-from glances.processes import glances_processes
+from glances.processes import glances_processes, sort_processes_key_list
+from glances.outputs.glances_unicode import unicode_message
 from glances.timer import Timer
 
 # Import curses library for "normal" operating system
@@ -38,7 +38,7 @@ try:
 except ImportError:
     logger.critical("Curses module not found. Glances cannot start in standalone mode.")
     if WINDOWS:
-	    logger.critical("For Windows you can try installing windows-curses with pip install.")
+        logger.critical("For Windows you can try installing windows-curses with pip install.")
     sys.exit(1)
 
 
@@ -58,6 +58,7 @@ class _GlancesCurses(object):
         # '4' > Enable or disable quicklook
         # '5' > Enable or disable top menu
         '6': {'switch': 'meangpu'},
+        '9': {'switch': 'theme_white'},
         '/': {'switch': 'process_short_name'},
         'a': {'sort_key': 'auto'},
         'A': {'switch': 'disable_amps'},
@@ -76,6 +77,7 @@ class _GlancesCurses(object):
         'h': {'switch': 'help_tag'},
         'i': {'sort_key': 'io_counters'},
         'I': {'switch': 'disable_ip'},
+        'j': {'switch': 'programs'},
         # 'k' > Kill selected process
         'K': {'switch': 'disable_connections'},
         'l': {'switch': 'disable_alert'},
@@ -102,19 +104,30 @@ class _GlancesCurses(object):
         # "<" (left arrow) navigation through process sort
         # ">" (right arrow) navigation through process sort
         # 'UP' > Up in the server list
-        # 'DOWN' > Down in the server list    
+        # 'DOWN' > Down in the server list
     }
 
-    _sort_loop = ['cpu_percent', 'memory_percent', 'username',
-                  'cpu_times', 'io_counters', 'name']
+    _sort_loop = sort_processes_key_list
 
     # Define top menu
     _top = ['quicklook', 'cpu', 'percpu', 'gpu', 'mem', 'memswap', 'load']
     _quicklook_max_width = 68
 
     # Define left sidebar
-    _left_sidebar = ['network', 'connections', 'wifi', 'ports', 'diskio', 'fs',
-                     'irq', 'folders', 'raid', 'smart', 'sensors', 'now']
+    _left_sidebar = [
+        'network',
+        'connections',
+        'wifi',
+        'ports',
+        'diskio',
+        'fs',
+        'irq',
+        'folders',
+        'raid',
+        'smart',
+        'sensors',
+        'now',
+    ]
     _left_sidebar_min_width = 23
     _left_sidebar_max_width = 34
 
@@ -209,8 +222,7 @@ class _GlancesCurses(object):
         try:
             if hasattr(curses, 'start_color'):
                 curses.start_color()
-                logger.debug(
-                    'Curses interface compatible with {} colors'.format(curses.COLORS))
+                logger.debug('Curses interface compatible with {} colors'.format(curses.COLORS))
             if hasattr(curses, 'use_default_colors'):
                 curses.use_default_colors()
         except Exception as e:
@@ -319,11 +331,11 @@ class _GlancesCurses(object):
             'WARNING_LOG': self.ifWARNING_color,
             'CRITICAL_LOG': self.ifCRITICAL_color,
             'PASSWORD': curses.A_PROTECT,
-            'SELECTED': self.selected_color
+            'SELECTED': self.selected_color,
         }
 
     def set_cursor(self, value):
-        """Configure the curse cursor apparence.
+        """Configure the curse cursor appearance.
 
         0: invisible
         1: visible
@@ -338,23 +350,45 @@ class _GlancesCurses(object):
     def get_key(self, window):
         # @TODO: Check issue #163
         ret = window.getch()
-        logger.debug("Keypressed (code: %s)" % ret)
         return ret
 
     def __catch_key(self, return_to_browser=False):
         # Catch the pressed key
         self.pressedkey = self.get_key(self.term_window)
+        if self.pressedkey == -1:
+            return -1
 
         # Actions (available in the global hotkey dict)...
+        logger.debug("Keypressed (code: {})".format(self.pressedkey))
         for hotkey in self._hotkeys:
             if self.pressedkey == ord(hotkey) and 'switch' in self._hotkeys[hotkey]:
-                setattr(self.args,
+                # Get the option name
+                # Ex: disable_foo return foo
+                #     enable_foo_bar return foo_bar
+                option = '_'.join(self._hotkeys[hotkey]['switch'].split('_')[1:])
+                if self._hotkeys[hotkey]['switch'].startswith('disable_'):
+                    # disable_ switch
+                    if getattr(self.args, self._hotkeys[hotkey]['switch']):
+                        enable(self.args, option)
+                    else:
+                        disable(self.args, option)
+                elif self._hotkeys[hotkey]['switch'].startswith('enable_'):
+                    # enable_ switch
+                    if getattr(self.args, self._hotkeys[hotkey]['switch']):
+                        disable(self.args, option)
+                    else:
+                        enable(self.args, option)
+                else:
+                    # Others switchs options (with no enable_ or disable_)
+                    setattr(
+                        self.args,
                         self._hotkeys[hotkey]['switch'],
-                        not getattr(self.args,
-                                    self._hotkeys[hotkey]['switch']))
+                        not getattr(self.args, self._hotkeys[hotkey]['switch']),
+                    )
             if self.pressedkey == ord(hotkey) and 'sort_key' in self._hotkeys[hotkey]:
-                glances_processes.set_sort_key(self._hotkeys[hotkey]['sort_key'],
-                                               self._hotkeys[hotkey]['sort_key'] == 'auto')
+                glances_processes.set_sort_key(
+                    self._hotkeys[hotkey]['sort_key'], self._hotkeys[hotkey]['sort_key'] == 'auto'
+                )
 
         # Other actions...
         if self.pressedkey == ord('\n'):
@@ -374,6 +408,9 @@ class _GlancesCurses(object):
                 self.disable_top()
             else:
                 self.enable_top()
+        elif self.pressedkey == ord('9'):
+            # '9' > Theme from black to white and reverse
+            self._init_colors()
         elif self.pressedkey == ord('e'):
             # 'e' > Enable/Disable process extended
             self.args.enable_process_extended = not self.args.enable_process_extended
@@ -426,8 +463,7 @@ class _GlancesCurses(object):
             if return_to_browser:
                 logger.info("Stop Glances client and return to the browser")
             else:
-                logger.info(
-                    "Stop Glances (keypressed: {})".format(self.pressedkey))
+                logger.info("Stop Glances (keypressed: {})".format(self.pressedkey))
         elif self.pressedkey == curses.KEY_F5:
             # "F5" manual refresh requested
             pass
@@ -491,7 +527,7 @@ class _GlancesCurses(object):
         self.column = 0
         self.next_column = 0
 
-    def new_line(self):
+    def new_line(self, separator=False):
         """New line in the curses interface."""
         self.line = self.next_line
 
@@ -499,10 +535,27 @@ class _GlancesCurses(object):
         """New column in the curses interface."""
         self.column = self.next_column
 
+    def separator_line(self, color='TITLE'):
+        """New separator line in the curses interface."""
+        if not self.args.enable_separator:
+            return
+        self.new_line()
+        self.line -= 1
+        line_width = self.term_window.getmaxyx()[1] - self.column
+        self.term_window.addnstr(
+            self.line,
+            self.column,
+            unicode_message('MEDIUM_LINE', self.args) * line_width,
+            line_width,
+            self.colors_list[color],
+        )
+
     def __get_stat_display(self, stats, layer):
         """Return a dict of dict with all the stats display.
-        stats: Global stats dict
-        layer: ~ cs_status
+        # TODO: Drop extra parameter
+
+        :param stats: Global stats dict
+        :param layer: ~ cs_status
             "None": standalone or server mode
             "Connected": Client is connected to a Glances server
             "SNMP": Client is connected to a SNMP server
@@ -523,30 +576,25 @@ class _GlancesCurses(object):
             # Compute the plugin max size
             plugin_max_width = None
             if p in self._left_sidebar:
-                plugin_max_width = max(self._left_sidebar_min_width,
-                                       self.term_window.getmaxyx()[1] - 105)
-                plugin_max_width = min(self._left_sidebar_max_width,
-                                       plugin_max_width)
+                plugin_max_width = max(self._left_sidebar_min_width, self.term_window.getmaxyx()[1] - 105)
+                plugin_max_width = min(self._left_sidebar_max_width, plugin_max_width)
 
             # Get the view
-            ret[p] = stats.get_plugin(p).get_stats_display(args=self.args,
-                                                           max_width=plugin_max_width)
+            ret[p] = stats.get_plugin(p).get_stats_display(args=self.args, max_width=plugin_max_width)
 
         return ret
 
     def display(self, stats, cs_status=None):
         """Display stats on the screen.
 
-        stats: Stats database to display
-        cs_status:
+        :param stats: Stats database to display
+        :param cs_status:
             "None": standalone or server mode
             "Connected": Client is connected to a Glances server
             "SNMP": Client is connected to a SNMP server
             "Disconnected": Client is disconnected from the server
 
-        Return:
-            True if the stats have been displayed
-            False if the help have been displayed
+        :return: True if the stats have been displayed else False if the help have been displayed
         """
         # Init the internal line/column for Glances Curses
         self.init_line_column()
@@ -554,21 +602,23 @@ class _GlancesCurses(object):
         # Update the stats messages
         ###########################
 
-        # Get all the plugins but quicklook and proceslist
+        # Get all the plugins but quicklook and process list
         self.args.cs_status = cs_status
         __stat_display = self.__get_stat_display(stats, layer=cs_status)
 
         # Adapt number of processes to the available space
         max_processes_displayed = (
-            self.term_window.getmaxyx()[0] - 11 -
-            (0 if 'docker' not in __stat_display else
-                self.get_stats_display_height(__stat_display["docker"])) -
-            (0 if 'processcount' not in __stat_display else
-                self.get_stats_display_height(__stat_display["processcount"])) -
-            (0 if 'amps' not in __stat_display else
-                self.get_stats_display_height(__stat_display["amps"])) -
-            (0 if 'alert' not in __stat_display else
-                self.get_stats_display_height(__stat_display["alert"])))
+            self.term_window.getmaxyx()[0]
+            - 11
+            - (0 if 'docker' not in __stat_display else self.get_stats_display_height(__stat_display["docker"]))
+            - (
+                0
+                if 'processcount' not in __stat_display
+                else self.get_stats_display_height(__stat_display["processcount"])
+            )
+            - (0 if 'amps' not in __stat_display else self.get_stats_display_height(__stat_display["amps"]))
+            - (0 if 'alert' not in __stat_display else self.get_stats_display_height(__stat_display["alert"]))
+        )
 
         try:
             if self.args.enable_process_extended:
@@ -577,14 +627,12 @@ class _GlancesCurses(object):
             pass
         if max_processes_displayed < 0:
             max_processes_displayed = 0
-        if (glances_processes.max_processes is None or
-                glances_processes.max_processes != max_processes_displayed):
+        if glances_processes.max_processes is None or glances_processes.max_processes != max_processes_displayed:
             logger.debug("Set number of displayed processes to {}".format(max_processes_displayed))
             glances_processes.max_processes = max_processes_displayed
 
         # Get the processlist
-        __stat_display["processlist"] = stats.get_plugin(
-            'processlist').get_stats_display(args=self.args)
+        __stat_display["processlist"] = stats.get_plugin('processlist').get_stats_display(args=self.args)
 
         # Display the stats on the curses interface
         ###########################################
@@ -592,21 +640,23 @@ class _GlancesCurses(object):
         # Help screen (on top of the other stats)
         if self.args.help_tag:
             # Display the stats...
-            self.display_plugin(
-                stats.get_plugin('help').get_stats_display(args=self.args))
+            self.display_plugin(stats.get_plugin('help').get_stats_display(args=self.args))
             # ... and exit
             return False
 
         # =====================================
         # Display first line (system+ip+uptime)
-        # Optionnaly: Cloud on second line
+        # Optionally: Cloud on second line
         # =====================================
         self.__display_header(__stat_display)
+        self.separator_line()
 
         # ==============================================================
         # Display second line (<SUMMARY>+CPU|PERCPU+<GPU>+LOAD+MEM+SWAP)
         # ==============================================================
         self.__display_top(__stat_display, stats)
+        self.init_column()
+        self.separator_line()
 
         # ==================================================================
         # Display left sidebar (NETWORK+PORTS+DISKIO+FS+SENSORS+Current time)
@@ -626,17 +676,18 @@ class _GlancesCurses(object):
         # Only in standalone mode (cs_status is None)
         if self.edit_filter and cs_status is None:
             new_filter = self.display_popup(
-                'Process filter pattern: \n\n' +
-                'Examples:\n' +
-                '- python\n' +
-                '- .*python.*\n' +
-                '- /usr/lib.*\n' +
-                '- name:.*nautilus.*\n' +
-                '- cmdline:.*glances.*\n' +
-                '- username:nicolargo\n' +
-                '- username:^root        ',
+                'Process filter pattern: \n\n'
+                + 'Examples:\n'
+                + '- python\n'
+                + '- .*python.*\n'
+                + '- /usr/lib.*\n'
+                + '- name:.*nautilus.*\n'
+                + '- cmdline:.*glances.*\n'
+                + '- username:nicolargo\n'
+                + '- username:^root        ',
                 popup_type='input',
-                input_value=glances_processes.process_filter_input)
+                input_value=glances_processes.process_filter_input,
+            )
             glances_processes.process_filter = new_filter
         elif self.edit_filter and cs_status is not None:
             self.display_popup('Process filter only available in standalone mode')
@@ -645,35 +696,48 @@ class _GlancesCurses(object):
         # Display kill process confirmation popup
         # Only in standalone mode (cs_status is None)
         if self.kill_process and cs_status is None:
-            selected_process_raw = stats.get_plugin('processlist').get_raw()[
-                self.args.cursor_position]
-            confirm = self.display_popup(
-                'Kill process: {} (pid: {}) ?\n\nConfirm ([y]es/[n]o): '.format(
-                    selected_process_raw['name'], 
-                    selected_process_raw['pid']), 
-                    popup_type='yesno')
-            if confirm.lower().startswith('y'):
-                try:
-                    ret_kill = glances_processes.kill(selected_process_raw['pid'])
-                except Exception as e:
-                    logger.error('Can not kill process {} ({})'.format(
-                        selected_process_raw['name'], e))
-                else:
-                    logger.info('Kill signal has been sent to process {} (return code: {})'.format(
-                        selected_process_raw['name'], ret_kill))
-
+            logger.info(stats.get_plugin('processlist').get_raw()[self.args.cursor_position])
+            self.kill(stats.get_plugin('processlist').get_raw()[self.args.cursor_position])
         elif self.kill_process and cs_status is not None:
-            self.display_popup(
-                'Kill process only available in standalone mode')
+            self.display_popup('Kill process only available for local processes')
         self.kill_process = False
 
-
         # Display graph generation popup
         if self.args.generate_graph:
             self.display_popup('Generate graph in {}'.format(self.args.export_graph_path))
 
         return True
 
+    def kill(self, process):
+        """Kill a process, or a list of process if the process has a childrens field.
+
+        :param process
+        :return: None
+        """
+        logger.debug("Selected process to kill: {}".format(process))
+
+        if 'childrens' in process:
+            pid_to_kill = process['childrens']
+        else:
+            pid_to_kill = [process['pid']]
+
+        confirm = self.display_popup(
+            'Kill process: {} (pid: {}) ?\n\nConfirm ([y]es/[n]o): '.format(
+                process['name'],
+                ', '.join(map(str, pid_to_kill)),
+            ),
+            popup_type='yesno',
+        )
+
+        if confirm.lower().startswith('y'):
+            for pid in pid_to_kill:
+                try:
+                    ret_kill = glances_processes.kill(pid)
+                except Exception as e:
+                    logger.error('Can not kill process {} ({})'.format(pid, e))
+                else:
+                    logger.info('Kill signal has been sent to process {} (return code: {})'.format(pid, ret_kill))
+
     def __display_header(self, stat_display):
         """Display the firsts lines (header) in the Curses interface.
 
@@ -687,21 +751,20 @@ class _GlancesCurses(object):
         for i in ['system', 'ip', 'uptime']:
             if i in stat_display:
                 l_uptime += self.get_stats_display_width(stat_display[i])
-        self.display_plugin(
-            stat_display["system"],
-            display_optional=(self.term_window.getmaxyx()[1] >= l_uptime))
+        self.display_plugin(stat_display["system"], display_optional=(self.term_window.getmaxyx()[1] >= l_uptime))
         self.space_between_column = 3
         if 'ip' in stat_display:
             self.new_column()
             self.display_plugin(stat_display["ip"])
         self.new_column()
         self.display_plugin(
-            stat_display["uptime"],
-            add_space=-(self.get_stats_display_width(stat_display["cloud"]) != 0))
-        # Second line (optional)
+            stat_display["uptime"], add_space=-(self.get_stats_display_width(stat_display["cloud"]) != 0)
+        )
         self.init_column()
-        self.new_line()
-        self.display_plugin(stat_display["cloud"])
+        if self.get_stats_display_width(stat_display["cloud"]) != 0:
+            # Second line (optional)
+            self.new_line()
+            self.display_plugin(stat_display["cloud"])
 
     def __display_top(self, stat_display, stats):
         """Display the second line in the Curses interface.
@@ -717,24 +780,33 @@ class _GlancesCurses(object):
         # Dict for plugins width
         plugin_widths = {}
         for p in self._top:
-            plugin_widths[p] = self.get_stats_display_width(stat_display.get(p, 0)) if hasattr(self.args, 'disable_' + p) else 0
+            plugin_widths[p] = (
+                self.get_stats_display_width(stat_display.get(p, 0)) if hasattr(self.args, 'disable_' + p) else 0
+            )
 
         # Width of all plugins
         stats_width = sum(itervalues(plugin_widths))
 
         # Number of plugin but quicklook
-        stats_number = sum([int(stat_display[p]['msgdict'] != []) for p in self._top if not getattr(self.args, 'disable_' + p)])
+        stats_number = sum(
+            [int(stat_display[p]['msgdict'] != []) for p in self._top if not getattr(self.args, 'disable_' + p)]
+        )
 
         if not self.args.disable_quicklook:
             # Quick look is in the place !
             if self.args.full_quicklook:
-                quicklook_width = self.term_window.getmaxyx()[1] - (stats_width + 8 + stats_number * self.space_between_column)
+                quicklook_width = self.term_window.getmaxyx()[1] - (
+                    stats_width + 8 + stats_number * self.space_between_column
+                )
             else:
-                quicklook_width = min(self.term_window.getmaxyx()[1] - (stats_width + 8 + stats_number * self.space_between_column),
-                                      self._quicklook_max_width - 5)
+                quicklook_width = min(
+                    self.term_window.getmaxyx()[1] - (stats_width + 8 + stats_number * self.space_between_column),
+                    self._quicklook_max_width - 5,
+                )
             try:
-                stat_display["quicklook"] = stats.get_plugin(
-                    'quicklook').get_stats_display(max_width=quicklook_width, args=self.args)
+                stat_display["quicklook"] = stats.get_plugin('quicklook').get_stats_display(
+                    max_width=quicklook_width, args=self.args
+                )
             except AttributeError as e:
                 logger.debug("Quicklook plugin not available (%s)" % e)
             else:
@@ -755,9 +827,15 @@ class _GlancesCurses(object):
                 # No space ? Remove optional stats
                 if self.space_between_column < 3:
                     plugin_display_optional[p] = False
-                    plugin_widths[p] = self.get_stats_display_width(stat_display[p], without_option=True) if hasattr(self.args, 'disable_' + p) else 0
+                    plugin_widths[p] = (
+                        self.get_stats_display_width(stat_display[p], without_option=True)
+                        if hasattr(self.args, 'disable_' + p)
+                        else 0
+                    )
                     stats_width = sum(itervalues(plugin_widths)) + 1
-                    self.space_between_column = max(1, int((self.term_window.getmaxyx()[1] - stats_width) / (stats_number - 1)))
+                    self.space_between_column = max(
+                        1, int((self.term_window.getmaxyx()[1] - stats_width) / (stats_number - 1))
+                    )
         else:
             self.space_between_column = 0
 
@@ -766,8 +844,7 @@ class _GlancesCurses(object):
             if p == 'quicklook':
                 continue
             if p in stat_display:
-                self.display_plugin(stat_display[p],
-                                    display_optional=plugin_display_optional[p])
+                self.display_plugin(stat_display[p], display_optional=plugin_display_optional[p])
             if p != 'load':
                 # Skip last column
                 self.new_column()
@@ -786,8 +863,7 @@ class _GlancesCurses(object):
             return
 
         for p in self._left_sidebar:
-            if ((hasattr(self.args, 'enable_' + p) or
-                 hasattr(self.args, 'disable_' + p)) and p in stat_display):
+            if (hasattr(self.args, 'enable_' + p) or hasattr(self.args, 'disable_' + p)) and p in stat_display:
                 self.new_line()
                 self.display_plugin(stat_display[p])
 
@@ -806,31 +882,31 @@ class _GlancesCurses(object):
         # Display right sidebar
         self.new_column()
         for p in self._right_sidebar:
-            if ((hasattr(self.args, 'enable_' + p) or
-                 hasattr(self.args, 'disable_' + p)) and p in stat_display):
+            if (hasattr(self.args, 'enable_' + p) or hasattr(self.args, 'disable_' + p)) and p in stat_display:
                 if p not in p:
                     # Catch for issue #1470
                     continue
                 self.new_line()
                 if p == 'processlist':
-                    self.display_plugin(stat_display['processlist'],
-                                        display_optional=(self.term_window.getmaxyx()[1] > 102),
-                                        display_additional=(not MACOS),
-                                        max_y=(self.term_window.getmaxyx()[0] - self.get_stats_display_height(stat_display['alert']) - 2))
+                    self.display_plugin(
+                        stat_display['processlist'],
+                        display_optional=(self.term_window.getmaxyx()[1] > 102),
+                        display_additional=(not MACOS),
+                        max_y=(
+                            self.term_window.getmaxyx()[0] - self.get_stats_display_height(stat_display['alert']) - 2
+                        ),
+                    )
                 else:
                     self.display_plugin(stat_display[p])
 
-    def display_popup(self, message,
-                      size_x=None, size_y=None,
-                      duration=3,
-                      popup_type='info',
-                      input_size=30,
-                      input_value=None):
+    def display_popup(
+        self, message, size_x=None, size_y=None, duration=3, popup_type='info', input_size=30, input_value=None
+    ):
         """
         Display a centered popup.
 
-        popup_type='info'
-         Just an infotmation popup, no user interaction
+         popup_type: ='info'
+         Just an information popup, no user interaction
          Display a centered popup with the given message during duration seconds
          If size_x and size_y: set the popup size
          else set it automatically
@@ -881,58 +957,54 @@ class _GlancesCurses(object):
             self.wait(duration * 1000)
             return True
         elif popup_type == 'input':
-            # Create a subwindow for the text field
-            subpop = popup.derwin(1, input_size, 2, 2 + len(m))
-            subpop.attron(self.colors_list['FILTER'])
+            # Create a sub-window for the text field
+            sub_pop = popup.derwin(1, input_size, 2, 2 + len(m))
+            sub_pop.attron(self.colors_list['FILTER'])
             # Init the field with the current value
             if input_value is not None:
-                subpop.addnstr(0, 0, input_value, len(input_value))
+                sub_pop.addnstr(0, 0, input_value, len(input_value))
             # Display the popup
             popup.refresh()
-            subpop.refresh()
-            # Create the textbox inside the subwindows
+            sub_pop.refresh()
+            # Create the textbox inside the sub-windows
             self.set_cursor(2)
             self.term_window.keypad(1)
-            textbox = GlancesTextbox(subpop, insert_mode=True)
+            textbox = GlancesTextbox(sub_pop, insert_mode=True)
             textbox.edit()
             self.set_cursor(0)
             # self.term_window.keypad(0)
             if textbox.gather() != '':
-                logger.debug(
-                    "User enters the following string: %s" % textbox.gather())
+                logger.debug("User enters the following string: %s" % textbox.gather())
                 return textbox.gather()[:-1]
             else:
                 logger.debug("User centers an empty string")
                 return None
         elif popup_type == 'yesno':
-            # # Create a subwindow for the text field
-            subpop = popup.derwin(1, 2, len(sentence_list) + 1, len(m) + 2)
-            subpop.attron(self.colors_list['FILTER'])
+            # # Create a sub-window for the text field
+            sub_pop = popup.derwin(1, 2, len(sentence_list) + 1, len(m) + 2)
+            sub_pop.attron(self.colors_list['FILTER'])
             # Init the field with the current value
-            subpop.addnstr(0, 0, '', 0)
+            sub_pop.addnstr(0, 0, '', 0)
             # Display the popup
             popup.refresh()
-            subpop.refresh()
-            # Create the textbox inside the subwindows
+            sub_pop.refresh()
+            # Create the textbox inside the sub-windows
             self.set_cursor(2)
             self.term_window.keypad(1)
-            textbox = GlancesTextboxYesNo(subpop, insert_mode=False)
+            textbox = GlancesTextboxYesNo(sub_pop, insert_mode=False)
             textbox.edit()
             self.set_cursor(0)
             # self.term_window.keypad(0)
             return textbox.gather()
 
-    def display_plugin(self, plugin_stats,
-                       display_optional=True,
-                       display_additional=True,
-                       max_y=65535,
-                       add_space=0):
+    def display_plugin(self, plugin_stats, display_optional=True, display_additional=True, max_y=65535, add_space=0):
         """Display the plugin_stats on the screen.
 
-        If display_optional=True display the optional stats
-        If display_additional=True display additionnal stats
-        max_y: do not display line > max_y
-        add_space: add x space (line) after the plugin
+        :param plugin_stats:
+        :param display_optional: display the optional stats if True
+        :param display_additional: display additional stats if True
+        :param max_y: do not display line > max_y
+        :param add_space: add x space (line) after the plugin
         """
         # Exit if:
         # - the plugin_stats message is empty
@@ -987,13 +1059,16 @@ class _GlancesCurses(object):
             if not display_additional and m['additional']:
                 continue
             # Is it possible to display the stat with the current screen size
-            # !!! Crach if not try/except... Why ???
+            # !!! Crash if not try/except... Why ???
             try:
-                self.term_window.addnstr(y, x,
-                                         m['msg'],
-                                         # Do not disply outside the screen
-                                         screen_x - x,
-                                         self.colors_list[m['decoration']])
+                self.term_window.addnstr(
+                    y,
+                    x,
+                    m['msg'],
+                    # Do not display outside the screen
+                    screen_x - x,
+                    self.colors_list[m['decoration']],
+                )
             except Exception:
                 pass
             else:
@@ -1011,8 +1086,7 @@ class _GlancesCurses(object):
                     x_max = x
 
         # Compute the next Glances column/line position
-        self.next_column = max(
-            self.next_column, x_max + self.space_between_column)
+        self.next_column = max(self.next_column, x_max + self.space_between_column)
         self.next_line = max(self.next_line, y + self.space_between_line)
 
         # Have empty lines after the plugins
@@ -1025,8 +1099,8 @@ class _GlancesCurses(object):
     def flush(self, stats, cs_status=None):
         """Clear and update the screen.
 
-        stats: Stats database to display
-        cs_status:
+        :param stats: Stats database to display
+        :param cs_status:
             "None": standalone or server mode
             "Connected": Client is connected to the server
             "Disconnected": Client is disconnected from the server
@@ -1034,27 +1108,20 @@ class _GlancesCurses(object):
         self.erase()
         self.display(stats, cs_status=cs_status)
 
-    def update(self,
-               stats,
-               duration=3,
-               cs_status=None,
-               return_to_browser=False):
+    def update(self, stats, duration=3, cs_status=None, return_to_browser=False):
         """Update the screen.
 
-        INPUT
-        stats: Stats database to display
-        duration: duration of the loop
-        cs_status:
+        :param stats: Stats database to display
+        :param duration: duration of the loop
+        :param cs_status:
             "None": standalone or server mode
             "Connected": Client is connected to the server
             "Disconnected": Client is disconnected from the server
-        return_to_browser:
+        :param return_to_browser:
             True: Do not exist, return to the browser list
             False: Exit and return to the shell
 
-        OUTPUT
-        True: Exit key has been pressed
-        False: Others cases...
+        :return: True if exit key has been pressed else False
         """
         # Flush display
         self.flush(stats, cs_status=cs_status)
@@ -1066,25 +1133,32 @@ class _GlancesCurses(object):
             duration = 0.1
 
         # Wait duration (in s) time
-        exitkey = False
+        isexitkey = False
         countdown = Timer(duration)
-        # Set the default timeout (in ms) for the getch method
-        self.term_window.timeout(int(duration * 1000))
-        while not countdown.finished() and not exitkey:
+        # Set the default timeout (in ms) between two getch
+        self.term_window.timeout(100)
+        while not countdown.finished() and not isexitkey:
             # Getkey
             pressedkey = self.__catch_key(return_to_browser=return_to_browser)
-            # Is it an exit key ?
-            exitkey = (pressedkey == ord('\x1b') or pressedkey == ord('q'))
+            isexitkey = pressedkey == ord('\x1b') or pressedkey == ord('q')
+
             if pressedkey == curses.KEY_F5:
-                # were asked to refresh
-                return exitkey
-            if not exitkey and pressedkey > -1:
+                # Were asked to refresh
+                return isexitkey
+
+            if isexitkey and self.args.help_tag:
+                # Quit from help should return to main screen, not exit #1874
+                self.args.help_tag = not self.args.help_tag
+                isexitkey = False
+                return isexitkey
+
+            if not isexitkey and pressedkey > -1:
                 # Redraw display
                 self.flush(stats, cs_status=cs_status)
                 # Overwrite the timeout with the countdown
-                self.term_window.timeout(int(countdown.get() * 1000))
+                self.wait(delay=int(countdown.get() * 1000))
 
-        return exitkey
+        return isexitkey
 
     def wait(self, delay=100):
         """Wait delay in ms"""
@@ -1095,12 +1169,27 @@ class _GlancesCurses(object):
         try:
             if without_option:
                 # Size without options
-                c = len(max(''.join([(u(u(nativestr(i['msg'])).encode('ascii', 'replace')) if not i['optional'] else "")
-                                     for i in curse_msg['msgdict']]).split('\n'), key=len))
+                c = len(
+                    max(
+                        ''.join(
+                            [
+                                (u(u(nativestr(i['msg'])).encode('ascii', 'replace')) if not i['optional'] else "")
+                                for i in curse_msg['msgdict']
+                            ]
+                        ).split('\n'),
+                        key=len,
+                    )
+                )
             else:
                 # Size with all options
-                c = len(max(''.join([u(u(nativestr(i['msg'])).encode('ascii', 'replace'))
-                                     for i in curse_msg['msgdict']]).split('\n'), key=len))
+                c = len(
+                    max(
+                        ''.join(
+                            [u(u(nativestr(i['msg'])).encode('ascii', 'replace')) for i in curse_msg['msgdict']]
+                        ).split('\n'),
+                        key=len,
+                    )
+                )
         except Exception as e:
             logger.debug('ERROR: Can not compute plugin width ({})'.format(e))
             return 0
@@ -1108,7 +1197,7 @@ class _GlancesCurses(object):
             return c
 
     def get_stats_display_height(self, curse_msg):
-        r"""Return the height of the formatted curses message.
+        """Return the height of the formatted curses message.
 
         The height is defined by the number of '\n' (new line).
         """
@@ -1136,7 +1225,6 @@ class GlancesCursesClient(_GlancesCurses):
 
 
 class GlancesTextbox(Textbox, object):
-
     def __init__(self, *args, **kwargs):
         super(GlancesTextbox, self).__init__(*args, **kwargs)
 
@@ -1149,7 +1237,6 @@ class GlancesTextbox(Textbox, object):
 
 
 class GlancesTextboxYesNo(Textbox, object):
-
     def __init__(self, *args, **kwargs):
         super(GlancesTextboxYesNo, self).__init__(*args, **kwargs)
 
