@@ -22,21 +22,23 @@
 import os
 import threading
 import time
+from copy import deepcopy
 
+from glances.compat import iterkeys, itervalues, nativestr, pretty_date
 from glances.logger import logger
-from glances.compat import iterkeys, itervalues, nativestr
-from glances.timer import getTimeSinceLastUpdate
 from glances.plugins.glances_plugin import GlancesPlugin
-from glances.processes import sort_stats as sort_stats_processes, weighted, glances_processes
+from glances.processes import sort_stats as sort_stats_processes, glances_processes
+from glances.timer import getTimeSinceLastUpdate
 
 # Docker-py library (optional and Linux-only)
 # https://github.com/docker/docker-py
 try:
     import docker
+    from dateutil import parser
 except Exception as e:
     import_error_tag = True
-    # Display debu message if import KeyError
-    logger.warning("Error loading Docker Python Lib. Docker plugin is disabled ({})".format(e))
+    # Display debug message if import KeyError
+    logger.warning("Error loading Docker deps Lib. Docker plugin is disabled ({})".format(e))
 else:
     import_error_tag = False
 
@@ -61,9 +63,10 @@ else:
 #                       {'name': 'io_w',
 #                        'description': 'Container IO bytes write per second',
 #                        'y_unit': 'Bps'}]
-items_history_list = [{'name': 'cpu_percent',
-                       'description': 'Container CPU consumption in %',
-                       'y_unit': '%'}]
+items_history_list = [{'name': 'cpu_percent', 'description': 'Container CPU consumption in %', 'y_unit': '%'}]
+
+# List of key to remove before export
+export_exclude_list = ['cpu', 'io', 'memory', 'network']
 
 
 class Plugin(GlancesPlugin):
@@ -74,11 +77,9 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(Plugin, self).__init__(args=args,
-                                     config=config,
-                                     items_history_list=items_history_list)
+        super(Plugin, self).__init__(args=args, config=config, items_history_list=items_history_list)
 
-        # The plgin can be disable using: args.disable_docker
+        # The plugin can be disabled using: args.disable_docker
         self.args = args
 
         # Default config keys
@@ -90,11 +91,25 @@ class Plugin(GlancesPlugin):
         # Init the Docker API
         self.docker_client = self.connect()
 
-        # Dict of thread (to grab stats asynchroniously, one thread is created by container)
+        # Dict of thread (to grab stats asynchronously, one thread is created per container)
         # key: Container Id
         # value: instance of ThreadDockerGrabber
         self.thread_list = {}
 
+        # Dict of Network stats (Storing previous network stats to compute Rx/s and Tx/s)
+        # key: Container Id
+        # value: network stats dict
+        self.network_old = {}
+
+        # Dict of Disk IO stats (Storing previous disk_io stats to compute Rx/s and Tx/s)
+        # key: Container Id
+        # value: network stats dict
+        self.io_old = {}
+
+        # Force a first update because we need two update to have the first stat
+        self.update()
+        self.refresh_timer.set(0)
+
     def exit(self):
         """Overwrite the exit method to close threads."""
         for t in itervalues(self.thread_list):
@@ -112,16 +127,25 @@ class Plugin(GlancesPlugin):
         - Only exports containers
         - The key is the first container name
         """
-        ret = []
         try:
-            ret = self.stats['containers']
+            ret = deepcopy(self.stats['containers'])
         except KeyError as e:
             logger.debug("docker plugin - Docker export error {}".format(e))
+            ret = []
+
+        # Remove fields uses to compute rate
+        for container in ret:
+            for i in export_exclude_list:
+                container.pop(i)
+
         return ret
 
     def connect(self):
         """Connect to the Docker server."""
         try:
+            # If the following line replace the next one, the issue #1878
+            # is reproduced (Docker containers information missing with Docker 20.10.x)
+            # So, for the moment disable the timeout option
             ret = docker.from_env()
         except Exception as e:
             logger.error("docker plugin - Can not connect to Docker ({})".format(e))
@@ -149,15 +173,15 @@ class Plugin(GlancesPlugin):
         # Init new stats
         stats = self.get_init_value()
 
-        # The Docker-py lib is mandatory
-        if import_error_tag:
+        # The Docker-py lib is mandatory and connection should be ok
+        if import_error_tag or self.docker_client is None:
             return self.stats
 
         if self.input_method == 'local':
             # Update stats
 
             # Docker version
-            # Exemple: {
+            # Example: {
             #     "KernelVersion": "3.16.4-tinycore64",
             #     "Arch": "amd64",
             #     "ApiVersion": "1.15",
@@ -193,14 +217,16 @@ class Plugin(GlancesPlugin):
                 if container.id not in self.thread_list:
                     # Thread did not exist in the internal dict
                     # Create it and add it to the internal dict
-                    logger.debug("{} plugin - Create thread for container {}".format(self.plugin_name, container.id[:12]))
+                    logger.debug(
+                        "{} plugin - Create thread for container {}".format(self.plugin_name, container.id[:12])
+                    )
                     t = ThreadDockerGrabber(container)
                     self.thread_list[container.id] = t
                     t.start()
 
             # Stop threads for non-existing containers
-            nonexisting_containers = set(iterkeys(self.thread_list)) - set([c.id for c in containers])
-            for container_id in nonexisting_containers:
+            absent_containers = set(iterkeys(self.thread_list)) - set([c.id for c in containers])
+            for container_id in absent_containers:
                 # Stop the thread
                 logger.debug("{} plugin - Stop thread for old container {}".format(self.plugin_name, container_id[:12]))
                 self.thread_list[container_id].stop()
@@ -210,12 +236,8 @@ class Plugin(GlancesPlugin):
             # Get stats for all containers
             stats['containers'] = []
             for container in containers:
-                # Only show specific containers
-                if not self.is_show(nativestr(container.name)):
-                    continue
-
-                # Do not take hiden container into account
-                if self.is_hide(nativestr(container.name)):
+                # Shall we display the stats ?
+                if not self.is_display(nativestr(container.name)):
                     continue
 
                 # Init the stats for the current container
@@ -231,20 +253,44 @@ class Plugin(GlancesPlugin):
                 # Container Image
                 container_stats['Image'] = container.image.tags
                 # Global stats (from attrs)
+                # Container Status
                 container_stats['Status'] = container.attrs['State']['Status']
-                container_stats['Command'] = container.attrs['Config']['Entrypoint']
+                # Container Command (see #1912)
+                container_stats['Command'] = []
+                if container.attrs['Config'].get('Entrypoint', None):
+                    container_stats['Command'].extend(container.attrs['Config'].get('Entrypoint', []))
+                if container.attrs['Config'].get('Cmd', None):
+                    container_stats['Command'].extend(container.attrs['Config'].get('Cmd', []))
+                if not container_stats['Command']:
+                    container_stats['Command'] = None
                 # Standards stats
+                # See https://docs.docker.com/engine/api/v1.41/#operation/ContainerStats
+                # Be aware that the API can change... (example see issue #1857)
                 if container_stats['Status'] in ('running', 'paused'):
+                    # CPU
                     container_stats['cpu'] = self.get_docker_cpu(container.id, self.thread_list[container.id].stats)
                     container_stats['cpu_percent'] = container_stats['cpu'].get('total', None)
-                    container_stats['memory'] = self.get_docker_memory(container.id, self.thread_list[container.id].stats)
+                    # MEM
+                    container_stats['memory'] = self.get_docker_memory(
+                        container.id, self.thread_list[container.id].stats
+                    )
                     container_stats['memory_usage'] = container_stats['memory'].get('usage', None)
+                    if container_stats['memory'].get('cache', None) is not None:
+                        container_stats['memory_usage'] -= container_stats['memory']['cache']
+                    # IO
                     container_stats['io'] = self.get_docker_io(container.id, self.thread_list[container.id].stats)
                     container_stats['io_r'] = container_stats['io'].get('ior', None)
                     container_stats['io_w'] = container_stats['io'].get('iow', None)
-                    container_stats['network'] = self.get_docker_network(container.id, self.thread_list[container.id].stats)
+                    # NET
+                    container_stats['network'] = self.get_docker_network(
+                        container.id, self.thread_list[container.id].stats
+                    )
                     container_stats['network_rx'] = container_stats['network'].get('rx', None)
                     container_stats['network_tx'] = container_stats['network'].get('tx', None)
+                    # Uptime
+                    container_stats['Uptime'] = pretty_date(
+                        parser.parse(container.attrs['State']['StartedAt']).replace(tzinfo=None)
+                    )
                 else:
                     container_stats['cpu'] = {}
                     container_stats['cpu_percent'] = None
@@ -256,6 +302,7 @@ class Plugin(GlancesPlugin):
                     container_stats['network'] = {}
                     container_stats['network_rx'] = None
                     container_stats['network_tx'] = None
+                    container_stats['Uptime'] = None
                 # Add current container stats to the stats list
                 stats['containers'].append(container_stats)
 
@@ -276,49 +323,39 @@ class Plugin(GlancesPlugin):
                all_stats is the output of the stats method of the Docker API
         Output: a dict {'total': 1.49}
         """
-        cpu_new = {}
-        ret = {'total': 0.0}
+        cpu_stats = {'total': 0.0}
 
-        # Read the stats
-        # For each container, you will find a pseudo-file cpuacct.stat,
-        # containing the CPU usage accumulated by the processes of the container.
-        # Those times are expressed in ticks of 1/USER_HZ of a second.
-        # On x86 systems, USER_HZ is 100.
         try:
-            cpu_new['total'] = all_stats['cpu_stats']['cpu_usage']['total_usage']
-            cpu_new['system'] = all_stats['cpu_stats']['system_cpu_usage']
-            cpu_new['nb_core'] = len(all_stats['cpu_stats']['cpu_usage']['percpu_usage'] or [])
+            cpu = {
+                'system': all_stats['cpu_stats']['system_cpu_usage'],
+                'total': all_stats['cpu_stats']['cpu_usage']['total_usage'],
+            }
+            precpu = {
+                'system': all_stats['precpu_stats']['system_cpu_usage'],
+                'total': all_stats['precpu_stats']['cpu_usage']['total_usage'],
+            }
+            # Issue #1857
+            # If either precpu_stats.online_cpus or cpu_stats.online_cpus is nil
+            # then for compatibility with older daemons the length of
+            # the corresponding cpu_usage.percpu_usage array should be used.
+            cpu['nb_core'] = all_stats['cpu_stats'].get('online_cpus', None)
+            if cpu['nb_core'] is None:
+                cpu['nb_core'] = len(all_stats['cpu_stats']['cpu_usage']['percpu_usage'] or [])
         except KeyError as e:
-            # all_stats do not have CPU information
             logger.debug("docker plugin - Cannot grab CPU usage for container {} ({})".format(container_id, e))
             logger.debug(all_stats)
         else:
-            # Previous CPU stats stored in the cpu_old variable
-            if not hasattr(self, 'cpu_old'):
-                # First call, we init the cpu_old variable
-                self.cpu_old = {}
-                try:
-                    self.cpu_old[container_id] = cpu_new
-                except (IOError, UnboundLocalError):
-                    pass
-
-            if container_id not in self.cpu_old:
-                try:
-                    self.cpu_old[container_id] = cpu_new
-                except (IOError, UnboundLocalError):
-                    pass
-            else:
-                #
-                cpu_delta = float(cpu_new['total'] - self.cpu_old[container_id]['total'])
-                system_delta = float(cpu_new['system'] - self.cpu_old[container_id]['system'])
-                if cpu_delta > 0.0 and system_delta > 0.0:
-                    ret['total'] = (cpu_delta / system_delta) * float(cpu_new['nb_core']) * 100
-
-                # Save stats to compute next stats
-                self.cpu_old[container_id] = cpu_new
+            try:
+                cpu_delta = cpu['total'] - precpu['total']
+                system_cpu_delta = cpu['system'] - precpu['system']
+                # CPU usage % = (cpu_delta / system_cpu_delta) * number_cpus * 100.0
+                cpu_stats['total'] = (cpu_delta / system_cpu_delta) * cpu['nb_core'] * 100.0
+            except TypeError as e:
+                logger.debug("docker plugin - Cannot compute CPU usage for container {} ({})".format(container_id, e))
+                logger.debug(all_stats)
 
         # Return the stats
-        return ret
+        return cpu_stats
 
     def get_docker_memory(self, container_id, all_stats):
         """Return the container MEMORY.
@@ -327,20 +364,28 @@ class Plugin(GlancesPlugin):
                all_stats is the output of the stats method of the Docker API
         Output: a dict {'rss': 1015808, 'cache': 356352,  'usage': ..., 'max_usage': ...}
         """
-        ret = {}
+        memory_stats = {}
         # Read the stats
         try:
-            ret['rss'] = all_stats['memory_stats']['stats']['rss']
-            ret['cache'] = all_stats['memory_stats']['stats']['cache']
-            ret['usage'] = all_stats['memory_stats']['usage']
-            ret['limit'] = all_stats['memory_stats']['limit']
-            ret['max_usage'] = all_stats['memory_stats']['max_usage']
+            # Mandatory fields
+            memory_stats['usage'] = all_stats['memory_stats']['usage']
+            memory_stats['limit'] = all_stats['memory_stats']['limit']
+            # Issue #1857
+            # Some stats are not always available in ['memory_stats']['stats']
+            if 'rss' in all_stats['memory_stats']['stats']:
+                memory_stats['rss'] = all_stats['memory_stats']['stats']['rss']
+            elif 'total_rss' in all_stats['memory_stats']['stats']:
+                memory_stats['rss'] = all_stats['memory_stats']['stats']['total_rss']
+            else:
+                memory_stats['rss'] = None
+            memory_stats['cache'] = all_stats['memory_stats']['stats'].get('cache', None)
+            memory_stats['max_usage'] = all_stats['memory_stats'].get('max_usage', None)
         except (KeyError, TypeError) as e:
             # all_stats do not have MEM information
             logger.debug("docker plugin - Cannot grab MEM usage for container {} ({})".format(container_id, e))
             logger.debug(all_stats)
         # Return the stats
-        return ret
+        return memory_stats
 
     def get_docker_network(self, container_id, all_stats):
         """Return the container network usage using the Docker API (v1.0 or higher).
@@ -349,15 +394,15 @@ class Plugin(GlancesPlugin):
         Output: a dict {'time_since_update': 3000, 'rx': 10, 'tx': 65}.
         with:
             time_since_update: number of seconds elapsed between the latest grab
-            rx: Number of byte received
-            tx: Number of byte transmited
+            rx: Number of bytes received
+            tx: Number of bytes transmitted
         """
         # Init the returned dict
         network_new = {}
 
         # Read the rx/tx stats (in bytes)
         try:
-            netcounters = all_stats["networks"]
+            net_stats = all_stats["networks"]
         except KeyError as e:
             # all_stats do not have NETWORK information
             logger.debug("docker plugin - Cannot grab NET usage for container {} ({})".format(container_id, e))
@@ -365,37 +410,26 @@ class Plugin(GlancesPlugin):
             # No fallback available...
             return network_new
 
-        # Previous network interface stats are stored in the network_old variable
-        if not hasattr(self, 'inetcounters_old'):
-            # First call, we init the network_old var
-            self.netcounters_old = {}
-            try:
-                self.netcounters_old[container_id] = netcounters
-            except (IOError, UnboundLocalError):
-                pass
-
-        if container_id not in self.netcounters_old:
-            try:
-                self.netcounters_old[container_id] = netcounters
-            except (IOError, UnboundLocalError):
-                pass
+        # Previous network interface stats are stored in the self.network_old variable
+        # By storing time data we enable Rx/s and Tx/s calculations in the XML/RPC API, which would otherwise
+        # be overly difficult work for users of the API
+        try:
+            network_new['cumulative_rx'] = net_stats["eth0"]["rx_bytes"]
+            network_new['cumulative_tx'] = net_stats["eth0"]["tx_bytes"]
+        except KeyError as e:
+            # all_stats do not have INTERFACE information
+            logger.debug(
+                "docker plugin - Cannot grab network interface usage for container {} ({})".format(container_id, e)
+            )
+            logger.debug(all_stats)
         else:
-            # By storing time data we enable Rx/s and Tx/s calculations in the
-            # XML/RPC API, which would otherwise be overly difficult work
-            # for users of the API
-            try:
-                network_new['time_since_update'] = getTimeSinceLastUpdate('docker_net_{}'.format(container_id))
-                network_new['rx'] = netcounters["eth0"]["rx_bytes"] - self.netcounters_old[container_id]["eth0"]["rx_bytes"]
-                network_new['tx'] = netcounters["eth0"]["tx_bytes"] - self.netcounters_old[container_id]["eth0"]["tx_bytes"]
-                network_new['cumulative_rx'] = netcounters["eth0"]["rx_bytes"]
-                network_new['cumulative_tx'] = netcounters["eth0"]["tx_bytes"]
-            except KeyError as e:
-                # all_stats do not have INTERFACE information
-                logger.debug("docker plugin - Cannot grab network interface usage for container {} ({})".format(container_id, e))
-                logger.debug(all_stats)
+            network_new['time_since_update'] = getTimeSinceLastUpdate('docker_net_{}'.format(container_id))
+            if container_id in self.network_old:
+                network_new['rx'] = network_new['cumulative_rx'] - self.network_old[container_id]['cumulative_rx']
+                network_new['tx'] = network_new['cumulative_tx'] - self.network_old[container_id]['cumulative_tx']
 
             # Save stats to compute next bitrate
-            self.netcounters_old[container_id] = netcounters
+            self.network_old[container_id] = network_new
 
         # Return the stats
         return network_new
@@ -407,15 +441,15 @@ class Plugin(GlancesPlugin):
         Output: a dict {'time_since_update': 3000, 'ior': 10, 'iow': 65}.
         with:
             time_since_update: number of seconds elapsed between the latest grab
-            ior: Number of byte readed
-            iow: Number of byte written
+            ior: Number of bytes read
+            iow: Number of bytes written
         """
         # Init the returned dict
         io_new = {}
 
         # Read the ior/iow stats (in bytes)
         try:
-            iocounters = all_stats["blkio_stats"]
+            io_stats = all_stats["blkio_stats"]
         except KeyError as e:
             # all_stats do not have io information
             logger.debug("docker plugin - Cannot grab block IO usage for container {} ({})".format(container_id, e))
@@ -423,42 +457,27 @@ class Plugin(GlancesPlugin):
             # No fallback available...
             return io_new
 
-        # Previous io interface stats are stored in the io_old variable
-        if not hasattr(self, 'iocounters_old'):
-            # First call, we init the io_old var
-            self.iocounters_old = {}
-            try:
-                self.iocounters_old[container_id] = iocounters
-            except (IOError, UnboundLocalError):
-                pass
+        # Previous io interface stats are stored in the self.io_old variable
+        # By storing time data we enable IoR/s and IoW/s calculations in the
+        # XML/RPC API, which would otherwise be overly difficult work
+        # for users of the API
+        try:
+            io_service_bytes_recursive = io_stats['io_service_bytes_recursive']
 
-        if container_id not in self.iocounters_old:
-            try:
-                self.iocounters_old[container_id] = iocounters
-            except (IOError, UnboundLocalError):
-                pass
+            # Read IOR and IOW value in the structure list of dict
+            io_new['cumulative_ior'] = [i for i in io_service_bytes_recursive if i['op'].lower() == 'read'][0]['value']
+            io_new['cumulative_iow'] = [i for i in io_service_bytes_recursive if i['op'].lower() == 'write'][0]['value']
+        except (TypeError, IndexError, KeyError, AttributeError) as e:
+            # all_stats do not have io information
+            logger.debug("docker plugin - Cannot grab block IO usage for container {} ({})".format(container_id, e))
         else:
-            # By storing time data we enable IoR/s and IoW/s calculations in the
-            # XML/RPC API, which would otherwise be overly difficult work
-            # for users of the API
-            try:
-                # Read IOR and IOW value in the structure list of dict
-                ior = [i for i in iocounters['io_service_bytes_recursive'] if i['op'] == 'Read'][0]['value']
-                iow = [i for i in iocounters['io_service_bytes_recursive'] if i['op'] == 'Write'][0]['value']
-                ior_old = [i for i in self.iocounters_old[container_id]['io_service_bytes_recursive'] if i['op'] == 'Read'][0]['value']
-                iow_old = [i for i in self.iocounters_old[container_id]['io_service_bytes_recursive'] if i['op'] == 'Write'][0]['value']
-            except (TypeError, IndexError, KeyError) as e:
-                # all_stats do not have io information
-                logger.debug("docker plugin - Cannot grab block IO usage for container {} ({})".format(container_id, e))
-            else:
-                io_new['time_since_update'] = getTimeSinceLastUpdate('docker_io_{}'.format(container_id))
-                io_new['ior'] = ior - ior_old
-                io_new['iow'] = iow - iow_old
-                io_new['cumulative_ior'] = ior
-                io_new['cumulative_iow'] = iow
+            io_new['time_since_update'] = getTimeSinceLastUpdate('docker_io_{}'.format(container_id))
+            if container_id in self.io_old:
+                io_new['ior'] = io_new['cumulative_ior'] - self.io_old[container_id]['cumulative_ior']
+                io_new['iow'] = io_new['cumulative_iow'] - self.io_old[container_id]['cumulative_iow']
 
-                # Save stats to compute next bitrate
-                self.iocounters_old[container_id] = iocounters
+            # Save stats to compute next bitrate
+            self.io_old[container_id] = io_new
 
         # Return the stats
         return io_new
@@ -482,33 +501,28 @@ class Plugin(GlancesPlugin):
         if 'containers' not in self.stats:
             return False
 
-        # Add specifics informations
+        # Add specifics information
         # Alert
         for i in self.stats['containers']:
             # Init the views for the current container (key = container name)
             self.views[i[self.get_key()]] = {'cpu': {}, 'mem': {}}
             # CPU alert
             if 'cpu' in i and 'total' in i['cpu']:
-                # Looking for specific CPU container threasold in the conf file
-                alert = self.get_alert(i['cpu']['total'],
-                                       header=i['name'] + '_cpu',
-                                       action_key=i['name'])
+                # Looking for specific CPU container threshold in the conf file
+                alert = self.get_alert(i['cpu']['total'], header=i['name'] + '_cpu', action_key=i['name'])
                 if alert == 'DEFAULT':
-                    # Not found ? Get back to default CPU threasold value
+                    # Not found ? Get back to default CPU threshold value
                     alert = self.get_alert(i['cpu']['total'], header='cpu')
                 self.views[i[self.get_key()]]['cpu']['decoration'] = alert
             # MEM alert
             if 'memory' in i and 'usage' in i['memory']:
-                # Looking for specific MEM container threasold in the conf file
-                alert = self.get_alert(i['memory']['usage'],
-                                       maximum=i['memory']['limit'],
-                                       header=i['name'] + '_mem',
-                                       action_key=i['name'])
+                # Looking for specific MEM container threshold in the conf file
+                alert = self.get_alert(
+                    i['memory']['usage'], maximum=i['memory']['limit'], header=i['name'] + '_mem', action_key=i['name']
+                )
                 if alert == 'DEFAULT':
-                    # Not found ? Get back to default MEM threasold value
-                    alert = self.get_alert(i['memory']['usage'],
-                                           maximum=i['memory']['limit'],
-                                           header='mem')
+                    # Not found ? Get back to default MEM threshold value
+                    alert = self.get_alert(i['memory']['usage'], maximum=i['memory']['limit'], header='mem')
                 self.views[i[self.get_key()]]['mem']['decoration'] = alert
 
         return True
@@ -519,9 +533,7 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist (and non null) and display plugin enable...
-        if not self.stats \
-           or 'containers' not in self.stats or len(self.stats['containers']) == 0 \
-           or self.is_disable():
+        if not self.stats or 'containers' not in self.stats or len(self.stats['containers']) == 0 or self.is_disabled():
             return ret
 
         # Build the string message
@@ -537,13 +549,16 @@ class Plugin(GlancesPlugin):
         ret.append(self.curse_new_line())
         # Get the maximum containers name
         # Max size is configurable. See feature request #1723.
-        name_max_width = min(self.config.get_int_value('docker', 'max_name_size', default=20),
-                             len(max(self.stats['containers'], 
-                                 key=lambda x: len(x['name']))['name']))
+        name_max_width = min(
+            self.config.get_int_value('docker', 'max_name_size', default=20) if self.config is not None else 20,
+            len(max(self.stats['containers'], key=lambda x: len(x['name']))['name']),
+        )
         msg = ' {:{width}}'.format('Name', width=name_max_width)
         ret.append(self.curse_add_line(msg))
         msg = '{:>10}'.format('Status')
         ret.append(self.curse_add_line(msg))
+        msg = '{:>10}'.format('Uptime')
+        ret.append(self.curse_add_line(msg))
         msg = '{:>6}'.format('CPU%')
         ret.append(self.curse_add_line(msg))
         msg = '{:>7}'.format('MEM')
@@ -564,28 +579,29 @@ class Plugin(GlancesPlugin):
         for container in self.stats['containers']:
             ret.append(self.curse_new_line())
             # Name
-            ret.append(self.curse_add_line(self._msg_name(container=container,
-                                                          max_width=name_max_width)))
+            ret.append(self.curse_add_line(self._msg_name(container=container, max_width=name_max_width)))
             # Status
             status = self.container_alert(container['Status'])
             msg = '{:>10}'.format(container['Status'][0:10])
             ret.append(self.curse_add_line(msg, status))
+            # Uptime
+            if container['Uptime']:
+                msg = '{:>10}'.format(container['Uptime'])
+            else:
+                msg = '{:>10}'.format('_')
+            ret.append(self.curse_add_line(msg, status))
             # CPU
             try:
                 msg = '{:>6.1f}'.format(container['cpu']['total'])
             except KeyError:
                 msg = '{:>6}'.format('_')
-            ret.append(self.curse_add_line(msg, self.get_views(item=container['name'],
-                                                               key='cpu',
-                                                               option='decoration')))
+            ret.append(self.curse_add_line(msg, self.get_views(item=container['name'], key='cpu', option='decoration')))
             # MEM
             try:
                 msg = '{:>7}'.format(self.auto_unit(container['memory']['usage']))
             except KeyError:
                 msg = '{:>7}'.format('_')
-            ret.append(self.curse_add_line(msg, self.get_views(item=container['name'],
-                                                               key='mem',
-                                                               option='decoration')))
+            ret.append(self.curse_add_line(msg, self.get_views(item=container['name'], key='mem', option='decoration')))
             try:
                 msg = '{:>7}'.format(self.auto_unit(container['memory']['limit']))
             except KeyError:
@@ -611,7 +627,12 @@ class Plugin(GlancesPlugin):
                 unit = 'b'
             for r in ['rx', 'tx']:
                 try:
-                    value = self.auto_unit(int(container['network'][r] // container['network']['time_since_update'] * to_bit)) + unit
+                    value = (
+                        self.auto_unit(
+                            int(container['network'][r] // container['network']['time_since_update'] * to_bit)
+                        )
+                        + unit
+                    )
                     msg = '{:>7}'.format(value)
                 except KeyError:
                     msg = '{:>7}'.format('_')
@@ -629,18 +650,18 @@ class Plugin(GlancesPlugin):
         """Build the container name."""
         name = container['name']
         if len(name) > max_width:
-            name = '_' + name[-max_width + 1:]
+            name = '_' + name[-max_width + 1 :]
         else:
             name = name[:max_width]
         return ' {:{width}}'.format(name, width=max_width)
 
     def container_alert(self, status):
         """Analyse the container status."""
-        if status in ('running'):
+        if status == 'running':
             return 'OK'
-        elif status in ('exited'):
+        elif status == 'exited':
             return 'WARNING'
-        elif status in ('dead'):
+        elif status == 'dead':
             return 'CRITICAL'
         else:
             return 'CAREFUL'
@@ -700,17 +721,15 @@ class ThreadDockerGrabber(threading.Thread):
 
     def stopped(self):
         """Return True is the thread is stopped."""
-        return self._stopper.isSet()
+        return self._stopper.is_set()
 
 
 def sort_stats(stats):
     # Sort Docker stats using the same function than processes
-    sortedby = 'cpu_percent'
-    sortedby_secondary = 'memory_usage'
+    sort_by = 'cpu_percent'
+    sort_by_secondary = 'memory_usage'
     if glances_processes.sort_key.startswith('memory'):
-        sortedby = 'memory_usage'
-        sortedby_secondary = 'cpu_percent'
-    sort_stats_processes(stats['containers'],
-                         sortedby=sortedby,
-                         sortedby_secondary=sortedby_secondary)
+        sort_by = 'memory_usage'
+        sort_by_secondary = 'cpu_percent'
+    sort_stats_processes(stats['containers'], sorted_by=sort_by, sorted_by_secondary=sort_by_secondary)
     return stats
