@@ -28,19 +28,17 @@ try:
     import py3nvml.py3nvml as pynvml
 except Exception as e:
     import_error_tag = True
-    # Display debu message if import KeyError
+    # Display debug message if import KeyError
     logger.warning("Missing Python Lib ({}), Nvidia GPU plugin is disabled".format(e))
 else:
     import_error_tag = False
 
 # Define the history items list
 # All items in this list will be historised if the --enable-history tag is set
-items_history_list = [{'name': 'proc',
-                       'description': 'GPU processor',
-                       'y_unit': '%'},
-                      {'name': 'mem',
-                       'description': 'Memory consumption',
-                       'y_unit': '%'}]
+items_history_list = [
+    {'name': 'proc', 'description': 'GPU processor', 'y_unit': '%'},
+    {'name': 'mem', 'description': 'Memory consumption', 'y_unit': '%'},
+]
 
 
 class Plugin(GlancesPlugin):
@@ -51,11 +49,9 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(Plugin, self).__init__(args=args,
-                                     config=config,
-                                     stats_init_value=[])
+        super(Plugin, self).__init__(args=args, config=config, stats_init_value=[])
 
-        # Init the NVidia API
+        # Init the Nvidia API
         self.init_nvidia()
 
         # We want to display the stat in the curse interface
@@ -88,8 +84,8 @@ class Plugin(GlancesPlugin):
         stats = self.get_init_value()
 
         if not self.nvml_ready:
-            # !!! 
-            # Uncomment to test on computer without GPU 
+            # !!!
+            # Uncomment to test on computer without GPU
             # One GPU sample:
             # self.stats = [
             #     {
@@ -138,13 +134,11 @@ class Plugin(GlancesPlugin):
         # Call the father's method
         super(Plugin, self).update_views()
 
-        # Add specifics informations
+        # Add specifics information
         # Alert
         for i in self.stats:
             # Init the views for the current GPU
-            self.views[i[self.get_key()]] = {'proc': {},
-                                             'mem': {},
-                                             'temperature': {}}
+            self.views[i[self.get_key()]] = {'proc': {}, 'mem': {}, 'temperature': {}}
             # Processor alert
             if 'proc' in i:
                 alert = self.get_alert(i['proc'], header='proc')
@@ -166,7 +160,7 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist, not empty (issue #871) and plugin not disabled
-        if not self.stats or (self.stats == []) or self.is_disable():
+        if not self.stats or (self.stats == []) or self.is_disabled():
             return ret
 
         # Check if all GPU have the same name
@@ -203,10 +197,11 @@ class Plugin(GlancesPlugin):
             else:
                 msg = '{:13}'.format('proc:')
             ret.append(self.curse_add_line(msg))
-            ret.append(self.curse_add_line(
-                mean_proc_msg, self.get_views(item=gpu_stats[self.get_key()],
-                                              key='proc',
-                                              option='decoration')))
+            ret.append(
+                self.curse_add_line(
+                    mean_proc_msg, self.get_views(item=gpu_stats[self.get_key()], key='proc', option='decoration')
+                )
+            )
             # New line
             ret.append(self.curse_new_line())
             # GPU MEM
@@ -221,10 +216,11 @@ class Plugin(GlancesPlugin):
             else:
                 msg = '{:13}'.format('mem:')
             ret.append(self.curse_add_line(msg))
-            ret.append(self.curse_add_line(
-                mean_mem_msg, self.get_views(item=gpu_stats[self.get_key()],
-                                             key='mem',
-                                             option='decoration')))
+            ret.append(
+                self.curse_add_line(
+                    mean_mem_msg, self.get_views(item=gpu_stats[self.get_key()], key='mem', option='decoration')
+                )
+            )
             # New line
             ret.append(self.curse_new_line())
             # GPU TEMPERATURE
@@ -237,17 +233,18 @@ class Plugin(GlancesPlugin):
                 if args.fahrenheit:
                     mean_temperature = to_fahrenheit(mean_temperature)
                     unit = 'F'
-                mean_temperature_msg = '{:>3.0f}{}'.format(mean_temperature,
-                                                           unit)
+                mean_temperature_msg = '{:>3.0f}{}'.format(mean_temperature, unit)
             if len(self.stats) > 1:
                 msg = '{:13}'.format('temp mean:')
             else:
                 msg = '{:13}'.format('temperature:')
             ret.append(self.curse_add_line(msg))
-            ret.append(self.curse_add_line(
-                mean_temperature_msg, self.get_views(item=gpu_stats[self.get_key()],
-                                                     key='temperature',
-                                                     option='decoration')))
+            ret.append(
+                self.curse_add_line(
+                    mean_temperature_msg,
+                    self.get_views(item=gpu_stats[self.get_key()], key='temperature', option='decoration'),
+                )
+            )
         else:
             # Multi GPU
             # Temperature is not displayed in this mode...
@@ -264,9 +261,7 @@ class Plugin(GlancesPlugin):
                     mem_msg = '{:>3.0f}%'.format(gpu_stats['mem'])
                 except (ValueError, TypeError):
                     mem_msg = '{:>4}'.format('N/A')
-                msg = '{}: {} mem: {}'.format(id_msg,
-                                              proc_msg,
-                                              mem_msg)
+                msg = '{}: {} mem: {}'.format(id_msg, proc_msg, mem_msg)
                 ret.append(self.curse_add_line(msg))
 
         return ret
@@ -277,7 +272,7 @@ class Plugin(GlancesPlugin):
 
         for index, device_handle in enumerate(self.device_handles):
             device_stats = dict()
-            # Dictionnary key is the GPU_ID
+            # Dictionary key is the GPU_ID
             device_stats['key'] = self.get_key()
             # GPU id (for multiple GPU, start at 0)
             device_stats['gpu_id'] = index
@@ -341,7 +336,6 @@ def get_proc(device_handle):
 def get_temperature(device_handle):
     """Get GPU device CPU consumption in percent."""
     try:
-        return pynvml.nvmlDeviceGetTemperature(device_handle,
-                                               pynvml.NVML_TEMPERATURE_GPU)
+        return pynvml.nvmlDeviceGetTemperature(device_handle, pynvml.NVML_TEMPERATURE_GPU)
     except pynvml.NVMLError:
         return None
