@@ -21,29 +21,57 @@
 from __future__ import unicode_literals
 
 import base64
-import operator
 
 from glances.timer import getTimeSinceLastUpdate
 from glances.plugins.glances_plugin import GlancesPlugin
-from glances.compat import n, u, b, nativestr
+from glances.compat import n
 from glances.logger import logger
 
 import psutil
 
+# {'interface_name': 'mpqemubr0-dummy',
+# 'alias': None,
+# 'time_since_update': 2.081636428833008,
+# 'cumulative_rx': 0,
+# 'rx': 0, 'cumulative_tx': 0, 'tx': 0, 'cumulative_cx': 0, 'cx': 0,
+# 'is_up': False,
+# 'speed': 0,
+# 'key': 'interface_name'}
+# Fields description
+fields_description = {
+    'interface_name': {'description': 'Interface name.', 'unit': 'string'},
+    'alias': {'description': 'Interface alias name (optional).', 'unit': 'string'},
+    'rx': {'description': 'The received/input rate (in bit per second).', 'unit': 'bps'},
+    'tx': {'description': 'The sent/output rate (in bit per second).', 'unit': 'bps'},
+    'cumulative_rx': {
+        'description': 'The number of bytes received through the interface (cumulative).',
+        'unit': 'bytes',
+    },
+    'cumulative_tx': {'description': 'The number of bytes sent through the interface (cumulative).', 'unit': 'bytes'},
+    'speed': {
+        'description': 'Maximum interface speed (in bit per second). Can return 0 on some operating-system.',
+        'unit': 'bps',
+    },
+    'is_up': {'description': 'Is the interface up ?', 'unit': 'bool'},
+    'time_since_update': {'description': 'Number of seconds since last update.', 'unit': 'seconds'},
+}
+
 # SNMP OID
 # http://www.net-snmp.org/docs/mibs/interfaces.html
 # Dict key = interface_name
-snmp_oid = {'default': {'interface_name': '1.3.6.1.2.1.2.2.1.2',
-                        'cumulative_rx': '1.3.6.1.2.1.2.2.1.10',
-                        'cumulative_tx': '1.3.6.1.2.1.2.2.1.16'}}
+snmp_oid = {
+    'default': {
+        'interface_name': '1.3.6.1.2.1.2.2.1.2',
+        'cumulative_rx': '1.3.6.1.2.1.2.2.1.10',
+        'cumulative_tx': '1.3.6.1.2.1.2.2.1.16',
+    }
+}
 
 # Define the history items list
-items_history_list = [{'name': 'rx',
-                       'description': 'Download rate per second',
-                       'y_unit': 'bit/s'},
-                      {'name': 'tx',
-                       'description': 'Upload rate per second',
-                       'y_unit': 'bit/s'}]
+items_history_list = [
+    {'name': 'rx', 'description': 'Download rate per second', 'y_unit': 'bit/s'},
+    {'name': 'tx', 'description': 'Upload rate per second', 'y_unit': 'bit/s'},
+]
 
 
 class Plugin(GlancesPlugin):
@@ -54,31 +82,38 @@ class Plugin(GlancesPlugin):
 
     def __init__(self, args=None, config=None):
         """Init the plugin."""
-        super(Plugin, self).__init__(args=args,
-                                     config=config,
-                                     items_history_list=items_history_list,
-                                     stats_init_value=[])
+        super(Plugin, self).__init__(
+            args=args,
+            config=config,
+            items_history_list=items_history_list,
+            fields_description=fields_description,
+            stats_init_value=[],
+        )
 
         # We want to display the stat in the curse interface
         self.display_curse = True
+
         # Hide stats if it has never been != 0
         if config is not None:
-            self.hide_zero = config.get_bool_value(
-                self.plugin_name, 'hide_zero', default=False)
+            self.hide_zero = config.get_bool_value(self.plugin_name, 'hide_zero', default=False)
         else:
             self.hide_zero = False
         self.hide_zero_fields = ['rx', 'tx']
 
+        # Force a first update because we need two update to have the first stat
+        self.update()
+        self.refresh_timer.set(0)
+
     def get_key(self):
         """Return the key of the list."""
         return 'interface_name'
 
-    @GlancesPlugin._check_decorator
+    # @GlancesPlugin._check_decorator
     @GlancesPlugin._log_result_decorator
     def update(self):
         """Update network stats using the input method.
 
-        Stats is a list of dict (one dict per interface)
+        :return: list of stats dict (one dict per interface)
         """
         # Init new stats
         stats = self.get_init_value()
@@ -88,16 +123,16 @@ class Plugin(GlancesPlugin):
 
             # Grab network interface stat using the psutil net_io_counter method
             try:
-                netiocounters = psutil.net_io_counters(pernic=True)
+                net_io_counters = psutil.net_io_counters(pernic=True)
             except UnicodeDecodeError as e:
                 logger.debug('Can not get network interface counters ({})'.format(e))
                 return self.stats
 
             # Grab interface's status (issue #765)
             # Grab interface's speed (issue #718)
-            netstatus = {}
+            net_status = {}
             try:
-                netstatus = psutil.net_if_stats()
+                net_status = psutil.net_if_stats()
             except OSError as e:
                 # see psutil #797/glances #1106
                 logger.debug('Can not get network interface status ({})'.format(e))
@@ -106,7 +141,7 @@ class Plugin(GlancesPlugin):
             if not hasattr(self, 'network_old'):
                 # First call, we init the network_old var
                 try:
-                    self.network_old = netiocounters
+                    self.network_old = net_io_counters
                 except (IOError, UnboundLocalError):
                     pass
                 return self.stats
@@ -117,11 +152,11 @@ class Plugin(GlancesPlugin):
             time_since_update = getTimeSinceLastUpdate('net')
 
             # Loop over interfaces
-            network_new = netiocounters
+            network_new = net_io_counters
             for net in network_new:
                 # Do not take hidden interface into account
                 # or KeyError: 'eth0' when interface is not connected #1348
-                if self.is_hide(net) or net not in netstatus:
+                if not self.is_display(net) or net not in net_status:
                     continue
                 try:
                     cumulative_rx = network_new[net].bytes_recv
@@ -130,22 +165,24 @@ class Plugin(GlancesPlugin):
                     rx = cumulative_rx - self.network_old[net].bytes_recv
                     tx = cumulative_tx - self.network_old[net].bytes_sent
                     cx = rx + tx
-                    netstat = {'interface_name': n(net),
-                               'time_since_update': time_since_update,
-                               'cumulative_rx': cumulative_rx,
-                               'rx': rx,
-                               'cumulative_tx': cumulative_tx,
-                               'tx': tx,
-                               'cumulative_cx': cumulative_cx,
-                               'cx': cx,
-                               # Interface status
-                               'is_up': netstatus[net].isup,
-                               # Interface speed in Mbps, convert it to bps
-                               # Can be always 0 on some OSes
-                               'speed': netstatus[net].speed * 1048576,
-                               # Set the key for the dict
-                               'key': self.get_key()
-                               }
+                    netstat = {
+                        'interface_name': n(net),
+                        'alias': self.has_alias(n(net)),
+                        'time_since_update': time_since_update,
+                        'cumulative_rx': cumulative_rx,
+                        'rx': rx,
+                        'cumulative_tx': cumulative_tx,
+                        'tx': tx,
+                        'cumulative_cx': cumulative_cx,
+                        'cx': cx,
+                        # Interface status
+                        'is_up': net_status[net].isup,
+                        # Interface speed in Mbps, convert it to bps
+                        # Can be always 0 on some OSes
+                        'speed': net_status[net].speed * 1048576,
+                        # Set the key for the dict
+                        'key': self.get_key(),
+                    }
                 except KeyError:
                     continue
                 else:
@@ -160,17 +197,15 @@ class Plugin(GlancesPlugin):
 
             # SNMP bulk command to get all network interface in one shot
             try:
-                netiocounters = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name],
-                                                    bulk=True)
+                net_io_counters = self.get_stats_snmp(snmp_oid=snmp_oid[self.short_system_name], bulk=True)
             except KeyError:
-                netiocounters = self.get_stats_snmp(snmp_oid=snmp_oid['default'],
-                                                    bulk=True)
+                net_io_counters = self.get_stats_snmp(snmp_oid=snmp_oid['default'], bulk=True)
 
             # Previous network interface stats are stored in the network_old variable
             if not hasattr(self, 'network_old'):
                 # First call, we init the network_old var
                 try:
-                    self.network_old = netiocounters
+                    self.network_old = net_io_counters
                 except (IOError, UnboundLocalError):
                     pass
             else:
@@ -178,11 +213,11 @@ class Plugin(GlancesPlugin):
                 time_since_update = getTimeSinceLastUpdate('net')
 
                 # Loop over interfaces
-                network_new = netiocounters
+                network_new = net_io_counters
 
                 for net in network_new:
                     # Do not take hidden interface into account
-                    if self.is_hide(net):
+                    if not self.is_display(net):
                         continue
 
                     try:
@@ -204,13 +239,15 @@ class Plugin(GlancesPlugin):
                         cx = rx + tx
                         netstat = {
                             'interface_name': interface_name,
+                            'alias': self.has_alias(interface_name),
                             'time_since_update': time_since_update,
                             'cumulative_rx': cumulative_rx,
                             'rx': rx,
                             'cumulative_tx': cumulative_tx,
                             'tx': tx,
                             'cumulative_cx': cumulative_cx,
-                            'cx': cx}
+                            'cx': cx,
+                        }
                     except KeyError:
                         continue
                     else:
@@ -233,27 +270,23 @@ class Plugin(GlancesPlugin):
         # Check if the stats should be hidden
         self.update_views_hidden()
 
-        # Add specifics informations
+        # Add specifics information
         # Alert
         for i in self.get_raw():
-            ifrealname = i['interface_name'].split(':')[0]
+            if_real_name = i['interface_name'].split(':')[0]
             # Convert rate in bps (to be able to compare to interface speed)
             bps_rx = int(i['rx'] // i['time_since_update'] * 8)
             bps_tx = int(i['tx'] // i['time_since_update'] * 8)
 
-            # Decorate the bitrate with the configuration file thresolds
-            alert_rx = self.get_alert(bps_rx, header=ifrealname + '_rx')
-            alert_tx = self.get_alert(bps_tx, header=ifrealname + '_tx')
+            # Decorate the bitrate with the configuration file thresholds
+            alert_rx = self.get_alert(bps_rx, header=if_real_name + '_rx')
+            alert_tx = self.get_alert(bps_tx, header=if_real_name + '_tx')
             # If nothing is define in the configuration file...
             # ... then use the interface speed (not available on all systems)
             if alert_rx == 'DEFAULT' and 'speed' in i and i['speed'] != 0:
-                alert_rx = self.get_alert(current=bps_rx,
-                                          maximum=i['speed'],
-                                          header='rx')
+                alert_rx = self.get_alert(current=bps_rx, maximum=i['speed'], header='rx')
             if alert_tx == 'DEFAULT' and 'speed' in i and i['speed'] != 0:
-                alert_tx = self.get_alert(current=bps_tx,
-                                          maximum=i['speed'],
-                                          header='tx')
+                alert_tx = self.get_alert(current=bps_tx, maximum=i['speed'], header='tx')
             # then decorates
             self.views[i[self.get_key()]]['rx']['decoration'] = alert_rx
             self.views[i[self.get_key()]]['tx']['decoration'] = alert_tx
@@ -264,7 +297,7 @@ class Plugin(GlancesPlugin):
         ret = []
 
         # Only process if stats exist and display plugin enable...
-        if not self.stats or self.is_disable():
+        if not self.stats or self.is_disabled():
             return ret
 
         # Max size for the interface name
@@ -306,13 +339,13 @@ class Plugin(GlancesPlugin):
                 continue
             # Format stats
             # Is there an alias for the interface name ?
-            ifrealname = i['interface_name'].split(':')[0]
-            ifname = self.has_alias(i['interface_name'])
-            if ifname is None:
-                ifname = ifrealname
-            if len(ifname) > name_max_width:
+            if i['alias'] is None:
+                if_name = i['interface_name'].split(':')[0]
+            else:
+                if_name = i['alias']
+            if len(if_name) > name_max_width:
                 # Cut interface name if it is too long
-                ifname = '_' + ifname[-name_max_width + 1:]
+                if_name = '_' + if_name[-name_max_width + 1 :]
 
             if args.byte:
                 # Bytes per second (for dummy)
@@ -326,27 +359,33 @@ class Plugin(GlancesPlugin):
             if args.network_cumul:
                 rx = self.auto_unit(int(i['cumulative_rx'] * to_bit)) + unit
                 tx = self.auto_unit(int(i['cumulative_tx'] * to_bit)) + unit
-                sx = self.auto_unit(int(i['cumulative_rx'] * to_bit) +
-                                    int(i['cumulative_tx'] * to_bit)) + unit
+                sx = self.auto_unit(int(i['cumulative_rx'] * to_bit) + int(i['cumulative_tx'] * to_bit)) + unit
             else:
                 rx = self.auto_unit(int(i['rx'] // i['time_since_update'] * to_bit)) + unit
                 tx = self.auto_unit(int(i['tx'] // i['time_since_update'] * to_bit)) + unit
-                sx = self.auto_unit(int(i['rx'] // i['time_since_update'] * to_bit) +
-                                    int(i['tx'] // i['time_since_update'] * to_bit)) + unit
+                sx = (
+                    self.auto_unit(
+                        int(i['rx'] // i['time_since_update'] * to_bit)
+                        + int(i['tx'] // i['time_since_update'] * to_bit)
+                    )
+                    + unit
+                )
 
             # New line
             ret.append(self.curse_new_line())
-            msg = '{:{width}}'.format(ifname, width=name_max_width)
+            msg = '{:{width}}'.format(if_name, width=name_max_width)
             ret.append(self.curse_add_line(msg))
             if args.network_sum:
                 msg = '{:>14}'.format(sx)
                 ret.append(self.curse_add_line(msg))
             else:
                 msg = '{:>7}'.format(rx)
-                ret.append(self.curse_add_line(
-                    msg, self.get_views(item=i[self.get_key()], key='rx', option='decoration')))
+                ret.append(
+                    self.curse_add_line(msg, self.get_views(item=i[self.get_key()], key='rx', option='decoration'))
+                )
                 msg = '{:>7}'.format(tx)
-                ret.append(self.curse_add_line(
-                    msg, self.get_views(item=i[self.get_key()], key='tx', option='decoration')))
+                ret.append(
+                    self.curse_add_line(msg, self.get_views(item=i[self.get_key()], key='tx', option='decoration'))
+                )
 
         return ret
