@@ -28,23 +28,38 @@ import json
 import copy
 from operator import itemgetter
 
-from glances.compat import iterkeys, itervalues, listkeys, map, mean, nativestr
+from glances.compat import iterkeys, itervalues, listkeys, map, mean, nativestr, u
 from glances.actions import GlancesActions
 from glances.history import GlancesHistory
 from glances.logger import logger
 from glances.events import glances_events
 from glances.thresholds import glances_thresholds
-from glances.timer import Counter
+from glances.timer import Counter, Timer
+from glances.outputs.glances_unicode import unicode_message
+
+
+fields_unit_short = {'percent': '%'}
+
+fields_unit_type = {
+    'percent': 'float',
+    'percents': 'float',
+    'number': 'int',
+    'numbers': 'int',
+    'int': 'int',
+    'ints': 'int',
+    'float': 'float',
+    'floats': 'float',
+    'second': 'int',
+    'seconds': 'int',
+    'byte': 'int',
+    'bytes': 'int',
+}
 
 
 class GlancesPlugin(object):
     """Main class for Glances plugin."""
 
-    def __init__(self,
-                 args=None,
-                 config=None,
-                 items_history_list=None,
-                 stats_init_value={}):
+    def __init__(self, args=None, config=None, items_history_list=None, stats_init_value={}, fields_description=None):
         """Init the plugin of plugins class.
 
         All Glances' plugins should inherit from this class. Most of the
@@ -58,7 +73,7 @@ class GlancesPlugin(object):
         - the __init__ constructor: define the self.display_curse
         - the reset method: to set your self.stats variable to {} or []
         - the update method: where your self.stats variable is set
-        and optionnaly:
+        and optionally:
         - the get_key method: set the key of the dict (only for list of dict)
         - the update_view method: only if you need to trick your output
         - the msg_curse: define the curse (UI) message (if display_curse is True)
@@ -75,7 +90,7 @@ class GlancesPlugin(object):
         # Init the args
         self.args = args
 
-        # Init the default alignement (for curses)
+        # Init the default alignment (for curses)
         self._align = 'left'
 
         # Init the input method
@@ -86,11 +101,10 @@ class GlancesPlugin(object):
         self.items_history_list = items_history_list
         self.stats_history = self.init_stats_history()
 
-        # Init the limits (configuration keys) dictionnary
+        # Init the limits (configuration keys) dictionary
         self._limits = dict()
         if config is not None:
-            logger.debug('Load section {} in {}'.format(self.plugin_name,
-                                                        config.config_file_paths()))
+            logger.debug('Load section {} in {}'.format(self.plugin_name, config.config_file_paths()))
             self.load_limits(config=config)
 
         # Init the actions
@@ -104,6 +118,12 @@ class GlancesPlugin(object):
         self.hide_zero = False
         self.hide_zero_fields = []
 
+        # Set the initial refresh time to display stats the first time
+        self.refresh_timer = Timer(0)
+
+        # Init stats description
+        self.fields_description = fields_description
+
         # Init the stats
         self.stats_init_value = stats_init_value
         self.stats = None
@@ -124,7 +144,7 @@ class GlancesPlugin(object):
     def reset(self):
         """Reset the stats.
 
-        This method should be overwrited by childs' classes.
+        This method should be overwritten by child classes.
         """
         self.stats = self.get_init_value()
 
@@ -136,20 +156,19 @@ class GlancesPlugin(object):
         """Return the key of the list."""
         return None
 
-    def is_enable(self, plugin_name=None):
+    def is_enabled(self, plugin_name=None):
         """Return true if plugin is enabled."""
         if not plugin_name:
             plugin_name = self.plugin_name
         try:
             d = getattr(self.args, 'disable_' + plugin_name)
         except AttributeError:
-            return True
-        else:
-            return d is False
+            d = getattr(self.args, 'enable_' + plugin_name, True)
+        return d is False
 
-    def is_disable(self, plugin_name=None):
+    def is_disabled(self, plugin_name=None):
         """Return true if plugin is disabled."""
-        return not self.is_enable(plugin_name=plugin_name)
+        return not self.is_enabled(plugin_name=plugin_name)
 
     def _json_dumps(self, d):
         """Return the object 'd' in a JSON format.
@@ -190,21 +209,23 @@ class GlancesPlugin(object):
             for i in self.get_items_history_list():
                 if isinstance(self.get_export(), list):
                     # Stats is a list of data
-                    # Iter throught it (for exemple, iter throught network
-                    # interface)
-                    for l in self.get_export():
+                    # Iter through it (for example, iter through network interface)
+                    for l_export in self.get_export():
                         self.stats_history.add(
-                            nativestr(l[item_name]) + '_' + nativestr(i['name']),
-                            l[i['name']],
+                            nativestr(l_export[item_name]) + '_' + nativestr(i['name']),
+                            l_export[i['name']],
                             description=i['description'],
-                            history_max_size=self._limits['history_size'])
+                            history_max_size=self._limits['history_size'],
+                        )
                 else:
                     # Stats is not a list
                     # Add the item to the history directly
-                    self.stats_history.add(nativestr(i['name']),
-                                           self.get_export()[i['name']],
-                                           description=i['description'],
-                                           history_max_size=self._limits['history_size'])
+                    self.stats_history.add(
+                        nativestr(i['name']),
+                        self.get_export()[i['name']],
+                        description=i['description'],
+                        history_max_size=self._limits['history_size'],
+                    )
 
     def get_items_history_list(self):
         """Return the items history list."""
@@ -306,10 +327,24 @@ class GlancesPlugin(object):
     def sorted_stats(self):
         """Get the stats sorted by an alias (if present) or key."""
         key = self.get_key()
-        return sorted(self.stats, key=lambda stat: tuple(map(
-            lambda part: int(part) if part.isdigit() else part.lower(),
-            re.split(r"(\d+|\D+)", self.has_alias(stat[key]) or stat[key])
-        )))
+        try:
+            return sorted(
+                self.stats,
+                key=lambda stat: tuple(
+                    map(
+                        lambda part: int(part) if part.isdigit() else part.lower(),
+                        re.split(r"(\d+|\D+)", self.has_alias(stat[key]) or stat[key]),
+                    )
+                ),
+            )
+        except TypeError:
+            # Correct "Starting an alias with a number causes a crash #1885"
+            return sorted(
+                self.stats,
+                key=lambda stat: tuple(
+                    map(lambda part: part.lower(), re.split(r"(\d+|\D+)", self.has_alias(stat[key]) or stat[key]))
+                ),
+            )
 
     @short_system_name.setter
     def short_system_name(self, short_name):
@@ -330,29 +365,32 @@ class GlancesPlugin(object):
         from glances.snmp import GlancesSNMPClient
 
         # Init the SNMP request
-        clientsnmp = GlancesSNMPClient(host=self.args.client,
-                                       port=self.args.snmp_port,
-                                       version=self.args.snmp_version,
-                                       community=self.args.snmp_community)
+        snmp_client = GlancesSNMPClient(
+            host=self.args.client,
+            port=self.args.snmp_port,
+            version=self.args.snmp_version,
+            community=self.args.snmp_community,
+        )
 
         # Process the SNMP request
         ret = {}
         if bulk:
             # Bulk request
-            snmpresult = clientsnmp.getbulk_by_oid(0, 10, itervalues(*snmp_oid))
+            snmp_result = snmp_client.getbulk_by_oid(0, 10, itervalues(*snmp_oid))
 
             if len(snmp_oid) == 1:
                 # Bulk command for only one OID
                 # Note: key is the item indexed but the OID result
-                for item in snmpresult:
+                for item in snmp_result:
                     if iterkeys(item)[0].startswith(itervalues(snmp_oid)[0]):
-                        ret[iterkeys(snmp_oid)[0] + iterkeys(item)
-                            [0].split(itervalues(snmp_oid)[0])[1]] = itervalues(item)[0]
+                        ret[iterkeys(snmp_oid)[0] + iterkeys(item)[0].split(itervalues(snmp_oid)[0])[1]] = itervalues(
+                            item
+                        )[0]
             else:
                 # Build the internal dict with the SNMP result
                 # Note: key is the first item in the snmp_oid
                 index = 1
-                for item in snmpresult:
+                for item in snmp_result:
                     item_stats = {}
                     item_key = None
                     for key in iterkeys(snmp_oid):
@@ -367,11 +405,11 @@ class GlancesPlugin(object):
                     index += 1
         else:
             # Simple get request
-            snmpresult = clientsnmp.get_by_oid(itervalues(*snmp_oid))
+            snmp_result = snmp_client.get_by_oid(itervalues(*snmp_oid))
 
             # Build the internal dict with the SNMP result
             for key in iterkeys(snmp_oid):
-                ret[key] = snmpresult[snmp_oid[key]]
+                ret[key] = snmp_result[snmp_oid[key]]
 
         return ret
 
@@ -387,6 +425,10 @@ class GlancesPlugin(object):
         """Return the stats object in JSON format."""
         return self._json_dumps(self.stats)
 
+    def get_json(self):
+        """Return the stats object in JSON format."""
+        return self.get_stats()
+
     def get_stats_item(self, item):
         """Return the stats object for a specific item in JSON format.
 
@@ -418,17 +460,18 @@ class GlancesPlugin(object):
         if not isinstance(self.stats, list):
             return None
         else:
-            if value.isdigit():
+            if not isinstance(value, int) and value.isdigit():
                 value = int(value)
             try:
                 return self._json_dumps({value: [i for i in self.stats if i[item] == value]})
             except (KeyError, ValueError) as e:
-                logger.error(
-                    "Cannot get item({})=value({}) ({})".format(item, value, e))
+                logger.error("Cannot get item({})=value({}) ({})".format(item, value, e))
                 return None
 
     def update_views_hidden(self):
-        """If the self.hide_zero is set then update the hidden field of the view
+        """Update the hidden views
+
+        If the self.hide_zero is set then update the hidden field of the view
         It will check if all fields values are already be different from 0
         In this case, the hidden field is set to True
 
@@ -443,24 +486,19 @@ class GlancesPlugin(object):
         """
         if not self.hide_zero:
             return False
-        if (isinstance(self.get_raw(), list) and
-                self.get_raw() is not None and
-                self.get_key() is not None):
+        if isinstance(self.get_raw(), list) and self.get_raw() is not None and self.get_key() is not None:
             # Stats are stored in a list of dict (ex: NETWORK, FS...)
             for i in self.get_raw():
                 if any([i[f] for f in self.hide_zero_fields]):
                     for f in self.hide_zero_fields:
-                        self.views[i[self.get_key(
-                        )]][f]['_zero'] = self.views[i[self.get_key()]][f]['hidden']
+                        self.views[i[self.get_key()]][f]['_zero'] = self.views[i[self.get_key()]][f]['hidden']
                 for f in self.hide_zero_fields:
-                    self.views[i[self.get_key(
-                    )]][f]['hidden'] = self.views[i[self.get_key()]][f]['_zero'] and i[f] == 0
+                    self.views[i[self.get_key()]][f]['hidden'] = self.views[i[self.get_key()]][f]['_zero'] and i[f] == 0
         elif isinstance(self.get_raw(), dict) and self.get_raw() is not None:
-            # 
-            # Warning: This code has never been tested because 
+            #
+            # Warning: This code has never been tested because
             # no plugin with dict instance use the hidden function...
-            #                       vvvv
-            # 
+            #
             # Stats are stored in a dict (ex: CPU, LOAD...)
             for key in listkeys(self.get_raw()):
                 if any([self.get_raw()[f] for f in self.hide_zero_fields]):
@@ -480,35 +518,41 @@ class GlancesPlugin(object):
                 'optional': False,        >>> Is the stat optional
                 'additional': False,      >>> Is the stat provide additional information
                 'splittable': False,      >>> Is the stat can be cut (like process lon name)
-                'hidden': False,          >>> Is the stats should be hidden in the UI 
+                'hidden': False,          >>> Is the stats should be hidden in the UI
                 '_zero': True}            >>> For internal purpose only
         """
         ret = {}
 
-        if (isinstance(self.get_raw(), list) and
-                self.get_raw() is not None and
-                self.get_key() is not None):
+        if isinstance(self.get_raw(), list) and self.get_raw() is not None and self.get_key() is not None:
             # Stats are stored in a list of dict (ex: NETWORK, FS...)
             for i in self.get_raw():
                 # i[self.get_key()] is the interface name (example for NETWORK)
                 ret[i[self.get_key()]] = {}
                 for key in listkeys(i):
-                    value = {'decoration': 'DEFAULT',
-                             'optional': False,
-                             'additional': False,
-                             'splittable': False,
-                             'hidden': False,
-                             '_zero': self.views[i[self.get_key()]][key]['_zero'] if i[self.get_key()] in self.views and key in self.views[i[self.get_key()]] and 'zero' in self.views[i[self.get_key()]][key] else True}
+                    value = {
+                        'decoration': 'DEFAULT',
+                        'optional': False,
+                        'additional': False,
+                        'splittable': False,
+                        'hidden': False,
+                        '_zero': self.views[i[self.get_key()]][key]['_zero']
+                        if i[self.get_key()] in self.views
+                        and key in self.views[i[self.get_key()]]
+                        and 'zero' in self.views[i[self.get_key()]][key]
+                        else True,
+                    }
                     ret[i[self.get_key()]][key] = value
         elif isinstance(self.get_raw(), dict) and self.get_raw() is not None:
             # Stats are stored in a dict (ex: CPU, LOAD...)
             for key in listkeys(self.get_raw()):
-                value = {'decoration': 'DEFAULT',
-                         'optional': False,
-                         'additional': False,
-                         'splittable': False,
-                         'hidden': False,
-                         '_zero': self.views[key]['_zero'] if key in self.views and '_zero' in self.views[key] else True}
+                value = {
+                    'decoration': 'DEFAULT',
+                    'optional': False,
+                    'additional': False,
+                    'splittable': False,
+                    'hidden': False,
+                    '_zero': self.views[key]['_zero'] if key in self.views and '_zero' in self.views[key] else True,
+                }
                 ret[key] = value
 
         self.views = ret
@@ -585,6 +629,32 @@ class GlancesPlugin(object):
         """Set the limits to input_limits."""
         self._limits = input_limits
 
+    def set_refresh(self, value):
+        """Set the plugin refresh rate"""
+        self.set_limits('refresh', value)
+
+    def get_refresh(self):
+        """Return the plugin refresh time"""
+        ret = self.get_limits(item='refresh')
+        if ret is None:
+            ret = self.args.time
+        return ret
+
+    def get_refresh_time(self):
+        """Return the plugin refresh time"""
+        return self.get_refresh()
+
+    def set_limits(self, item, value):
+        """Set the limits object."""
+        self._limits['{}_{}'.format(self.plugin_name, item)] = value
+
+    def get_limits(self, item=None):
+        """Return the limits object."""
+        if item is None:
+            return self._limits
+        else:
+            return self._limits.get('{}_{}'.format(self.plugin_name, item), None)
+
     def get_stats_action(self):
         """Return stats for the action.
 
@@ -595,21 +665,23 @@ class GlancesPlugin(object):
         return self.stats
 
     def get_stat_name(self, header=""):
-        """"Return the stat name with an optional header"""
+        """ "Return the stat name with an optional header"""
         ret = self.plugin_name
         if header != "":
             ret += '_' + header
         return ret
 
-    def get_alert(self,
-                  current=0,
-                  minimum=0,
-                  maximum=100,
-                  highlight_zero=True,
-                  is_max=False,
-                  header="",
-                  action_key=None,
-                  log=False):
+    def get_alert(
+        self,
+        current=0,
+        minimum=0,
+        maximum=100,
+        highlight_zero=True,
+        is_max=False,
+        header="",
+        action_key=None,
+        log=False,
+    ):
         """Return the alert status relative to a current value.
 
         Use this function for minor stats.
@@ -665,7 +737,7 @@ class GlancesPlugin(object):
         log_str = ""
         if self.get_limit_log(stat_name=stat_name, default_action=log):
             # Add _LOG to the return string
-            # So stats will be highlited with a specific color
+            # So stats will be highlighted with a specific color
             log_str = "_LOG"
             # Add the log to the list
             glances_events.add(ret, stat_name.upper(), value)
@@ -679,17 +751,11 @@ class GlancesPlugin(object):
         # Default is 'OK'
         return ret + log_str
 
-    def manage_threshold(self,
-                         stat_name,
-                         trigger):
+    def manage_threshold(self, stat_name, trigger):
         """Manage the threshold for the current stat."""
         glances_thresholds.add(stat_name, trigger)
 
-    def manage_action(self,
-                      stat_name,
-                      trigger,
-                      header,
-                      action_key):
+    def manage_action(self, stat_name, trigger, header, action_key):
         """Manage the action for the current stat."""
         # Here is a command line for the current trigger ?
         try:
@@ -704,9 +770,9 @@ class GlancesPlugin(object):
                 action_key = header
 
             # A command line is available for the current alert
-            # 1) Build the {{mustache}} dictionnary
+            # 1) Build the {{mustache}} dictionary
             if isinstance(self.get_stats_action(), list):
-                # If the stats are stored in a list of dict (fs plugin for exemple)
+                # If the stats are stored in a list of dict (fs plugin for example)
                 # Return the dict for the current header
                 mustache_dict = {}
                 for item in self.get_stats_action():
@@ -717,53 +783,52 @@ class GlancesPlugin(object):
                 # Use the stats dict
                 mustache_dict = self.get_stats_action()
             # 2) Run the action
-            self.actions.run(
-                stat_name, trigger,
-                command, repeat, mustache_dict=mustache_dict)
+            self.actions.run(stat_name, trigger, command, repeat, mustache_dict=mustache_dict)
 
-    def get_alert_log(self,
-                      current=0,
-                      minimum=0,
-                      maximum=100,
-                      header="",
-                      action_key=None):
+    def get_alert_log(self, current=0, minimum=0, maximum=100, header="", action_key=None):
         """Get the alert log."""
-        return self.get_alert(current=current,
-                              minimum=minimum,
-                              maximum=maximum,
-                              header=header,
-                              action_key=action_key,
-                              log=True)
+        return self.get_alert(
+            current=current, minimum=minimum, maximum=maximum, header=header, action_key=action_key, log=True
+        )
 
-    def get_limit(self, criticity, stat_name=""):
+    def is_limit(self, criticality, stat_name=""):
+        """Return true if the criticality limit exist for the given stat_name"""
+        if stat_name == "":
+            return self.plugin_name + '_' + criticality in self._limits
+        else:
+            return stat_name + '_' + criticality in self._limits
+
+    def get_limit(self, criticality, stat_name=""):
         """Return the limit value for the alert."""
         # Get the limit for stat + header
-        # Exemple: network_wlan0_rx_careful
+        # Example: network_wlan0_rx_careful
         try:
-            limit = self._limits[stat_name + '_' + criticity]
+            limit = self._limits[stat_name + '_' + criticality]
         except KeyError:
             # Try fallback to plugin default limit
-            # Exemple: network_careful
-            limit = self._limits[self.plugin_name + '_' + criticity]
+            # Example: network_careful
+            limit = self._limits[self.plugin_name + '_' + criticality]
 
-        # logger.debug("{} {} value is {}".format(stat_name, criticity, limit))
+        # logger.debug("{} {} value is {}".format(stat_name, criticality, limit))
 
         # Return the limiter
         return limit
 
-    def get_limit_action(self, criticity, stat_name=""):
+    def get_limit_action(self, criticality, stat_name=""):
         """Return the tuple (action, repeat) for the alert.
 
         - action is a command line
         - repeat is a bool
         """
         # Get the action for stat + header
-        # Exemple: network_wlan0_rx_careful_action
+        # Example: network_wlan0_rx_careful_action
         # Action key available ?
-        ret = [(stat_name + '_' + criticity + '_action', False),
-               (stat_name + '_' + criticity + '_action_repeat', True),
-               (self.plugin_name + '_' + criticity + '_action', False),
-               (self.plugin_name + '_' + criticity + '_action_repeat', True)]
+        ret = [
+            (stat_name + '_' + criticality + '_action', False),
+            (stat_name + '_' + criticality + '_action_repeat', True),
+            (self.plugin_name + '_' + criticality + '_action', False),
+            (self.plugin_name + '_' + criticality + '_action_repeat', True),
+        ]
         for r in ret:
             if r[0] in self._limits:
                 return self._limits[r[0]], r[1]
@@ -774,16 +839,16 @@ class GlancesPlugin(object):
     def get_limit_log(self, stat_name, default_action=False):
         """Return the log tag for the alert."""
         # Get the log tag for stat + header
-        # Exemple: network_wlan0_rx_log
+        # Example: network_wlan0_rx_log
         try:
             log_tag = self._limits[stat_name + '_log']
         except KeyError:
             # Try fallback to plugin default log
-            # Exemple: network_log
+            # Example: network_log
             try:
                 log_tag = self._limits[self.plugin_name + '_log']
             except KeyError:
-                # By defaukt, log are disabled
+                # By default, log are disabled
                 return default_action
 
         # Return the action list
@@ -809,32 +874,38 @@ class GlancesPlugin(object):
 
     def is_show(self, value, header=""):
         """Return True if the value is in the show configuration list.
+
         If the show value is empty, return True (show by default)
 
         The show configuration list is defined in the glances.conf file.
-        It is a comma separed list of regexp.
+        It is a comma separated list of regexp.
         Example for diskio:
         show=sda.*
         """
         # @TODO: possible optimisation: create a re.compile list
-        if self.get_conf_value('show', header=header) == []:
-            return True
-        else:
-            return any(j for j in [re.match(i, value) for i in self.get_conf_value('show', header=header)])
+        return any(j for j in [re.match(i, value) for i in self.get_conf_value('show', header=header)])
 
     def is_hide(self, value, header=""):
         """Return True if the value is in the hide configuration list.
 
         The hide configuration list is defined in the glances.conf file.
-        It is a comma separed list of regexp.
+        It is a comma separated list of regexp.
         Example for diskio:
         hide=sda2,sda5,loop.*
         """
         # @TODO: possible optimisation: create a re.compile list
         return any(j for j in [re.match(i, value) for i in self.get_conf_value('hide', header=header)])
 
+    def is_display(self, value, header=""):
+        """Return True if the value should be displayed in the UI
+        """
+        if self.get_conf_value('show', header=header) != []:
+            return self.is_show(value, header=header)
+        else:
+            return not self.is_hide(value, header=header)
+
     def has_alias(self, header):
-        """Return the alias name for the relative header or None if nonexist."""
+        """Return the alias name for the relative header it it exists otherwise None."""
         try:
             # Force to lower case (issue #1126)
             return self._limits[self.plugin_name + '_' + header.lower() + '_' + 'alias'][0]
@@ -863,19 +934,13 @@ class GlancesPlugin(object):
             align_curse = self._align
 
         if max_width is not None:
-            ret = {'display': display_curse,
-                   'msgdict': self.msg_curse(args, max_width=max_width),
-                   'align': align_curse}
+            ret = {'display': display_curse, 'msgdict': self.msg_curse(args, max_width=max_width), 'align': align_curse}
         else:
-            ret = {'display': display_curse,
-                   'msgdict': self.msg_curse(args),
-                   'align': align_curse}
+            ret = {'display': display_curse, 'msgdict': self.msg_curse(args), 'align': align_curse}
 
         return ret
 
-    def curse_add_line(self, msg, decoration="DEFAULT",
-                       optional=False, additional=False,
-                       splittable=False):
+    def curse_add_line(self, msg, decoration="DEFAULT", optional=False, additional=False, splittable=False):
         """Return a dict with.
 
         Where:
@@ -893,20 +958,125 @@ class GlancesPlugin(object):
                 OK_LOG: Value is OK and logged
                 CAREFUL: Value is CAREFUL and non logged
                 CAREFUL_LOG: Value is CAREFUL and logged
-                WARNING: Value is WARINING and non logged
-                WARNING_LOG: Value is WARINING and logged
+                WARNING: Value is WARNING and non logged
+                WARNING_LOG: Value is WARNING and logged
                 CRITICAL: Value is CRITICAL and non logged
                 CRITICAL_LOG: Value is CRITICAL and logged
             optional: True if the stat is optional (display only if space is available)
             additional: True if the stat is additional (display only if space is available after optional)
-            spittable: Line can be splitted to fit on the screen (default is not)
+            spittable: Line can be split to fit on the screen (default is not)
         """
-        return {'msg': msg, 'decoration': decoration, 'optional': optional, 'additional': additional, 'splittable': splittable}
+        return {
+            'msg': msg,
+            'decoration': decoration,
+            'optional': optional,
+            'additional': additional,
+            'splittable': splittable,
+        }
 
     def curse_new_line(self):
         """Go to a new line."""
         return self.curse_add_line('\n')
 
+    def curse_add_stat(self, key, width=None, header='', separator='', trailer=''):
+        """Return a list of dict messages with the 'key: value' result
+
+          <=== width ===>
+        __key     : 80.5%__
+        | |       | |    |_ trailer
+        | |       | |_ self.stats[key]
+        | |       |_ separator
+        | |_ key
+        |_ trailer
+
+        Instead of:
+            msg = '  {:8}'.format('idle:')
+            ret.append(self.curse_add_line(msg, optional=self.get_views(key='idle', option='optional')))
+            msg = '{:5.1f}%'.format(self.stats['idle'])
+            ret.append(self.curse_add_line(msg, optional=self.get_views(key='idle', option='optional')))
+
+        Use:
+            ret.extend(self.curse_add_stat('idle', width=15, header='  '))
+
+        """
+        if key not in self.stats:
+            return []
+
+        # Check if a shortname is defined
+        if key in self.fields_description and 'short_name' in self.fields_description[key]:
+            key_name = self.fields_description[key]['short_name']
+        else:
+            key_name = key
+
+        # Check if unit is defined and get the short unit char in the unit_sort dict
+        if (
+            key in self.fields_description
+            and 'unit' in self.fields_description[key]
+            and self.fields_description[key]['unit'] in fields_unit_short
+        ):
+            # Get the shortname
+            unit_short = fields_unit_short[self.fields_description[key]['unit']]
+        else:
+            unit_short = ''
+
+        # Check if unit is defined and get the unit type unit_type dict
+        if (
+            key in self.fields_description
+            and 'unit' in self.fields_description[key]
+            and self.fields_description[key]['unit'] in fields_unit_type
+        ):
+            # Get the shortname
+            unit_type = fields_unit_type[self.fields_description[key]['unit']]
+        else:
+            unit_type = 'float'
+
+        # Is it a rate ? Yes, compute it thanks to the time_since_update key
+        if (
+            key in self.fields_description
+            and 'rate' in self.fields_description[key]
+            and self.fields_description[key]['rate'] is True
+        ):
+            value = self.stats[key] // self.stats['time_since_update']
+        else:
+            value = self.stats[key]
+
+        if width is None:
+            msg_item = header + '{}'.format(key_name) + separator
+            if unit_type == 'float':
+                msg_value = '{:.1f}{}'.format(value, unit_short) + trailer
+            elif 'min_symbol' in self.fields_description[key]:
+                msg_value = (
+                    '{}{}'.format(
+                        self.auto_unit(int(value), min_symbol=self.fields_description[key]['min_symbol']), unit_short
+                    )
+                    + trailer
+                )
+            else:
+                msg_value = '{}{}'.format(int(value), unit_short) + trailer
+        else:
+            # Define the size of the message
+            # item will be on the left
+            # value will be on the right
+            msg_item = header + '{:{width}}'.format(key_name, width=width - 7) + separator
+            if unit_type == 'float':
+                msg_value = '{:5.1f}{}'.format(value, unit_short) + trailer
+            elif 'min_symbol' in self.fields_description[key]:
+                msg_value = (
+                    '{:>5}{}'.format(
+                        self.auto_unit(int(value), min_symbol=self.fields_description[key]['min_symbol']), unit_short
+                    )
+                    + trailer
+                )
+            else:
+                msg_value = '{:>5}{}'.format(int(value), unit_short) + trailer
+        decoration = self.get_views(key=key, option='decoration')
+        optional = self.get_views(key=key, option='optional')
+
+        return [
+            self.curse_add_line(msg_item, optional=optional),
+            self.curse_add_line(msg_value, decoration=decoration, optional=optional),
+        ]
+
     @property
     def align(self):
         """Get the curse align."""
@@ -920,10 +1090,7 @@ class GlancesPlugin(object):
         """
         self._align = value
 
-    def auto_unit(self, number,
-                  low_precision=False,
-                  min_symbol='K'
-                  ):
+    def auto_unit(self, number, low_precision=False, min_symbol='K'):
         """Make a nice human-readable string out of number.
 
         Number of decimal places increases as quantity approaches 1.
@@ -937,11 +1104,11 @@ class GlancesPlugin(object):
 
         :low_precision: returns less decimal places potentially (default is False)
                         sacrificing precision for more readability.
-        :min_symbol: Do not approache if number < min_symbol (default is K)
+        :min_symbol: Do not approach if number < min_symbol (default is K)
         """
         symbols = ('K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y')
         if min_symbol in symbols:
-            symbols = symbols[symbols.index(min_symbol):]
+            symbols = symbols[symbols.index(min_symbol) :]
         prefix = {
             'Y': 1208925819614629174706176,
             'Z': 1180591620717411303424,
@@ -950,7 +1117,7 @@ class GlancesPlugin(object):
             'T': 1099511627776,
             'G': 1073741824,
             'M': 1048576,
-            'K': 1024
+            'K': 1024,
         }
 
         for symbol in reversed(symbols):
@@ -968,8 +1135,7 @@ class GlancesPlugin(object):
                         decimal_precision = min(1, decimal_precision)
                 elif symbol in 'K':
                     decimal_precision = 0
-                return '{:.{decimal}f}{symbol}'.format(
-                    value, decimal=decimal_precision, symbol=symbol)
+                return '{:.{decimal}f}{symbol}'.format(value, decimal=decimal_precision, symbol=symbol)
         return '{!s}'.format(number)
 
     def trend_msg(self, trend, significant=1):
@@ -981,35 +1147,55 @@ class GlancesPlugin(object):
         if trend is None:
             ret = ' '
         elif trend > significant:
-            ret = '/'
+            ret = unicode_message('ARROW_UP', self.args)
         elif trend < -significant:
-            ret = '\\'
+            ret = unicode_message('ARROW_DOWN', self.args)
         return ret
 
     def _check_decorator(fct):
-        """Check if the plugin is enabled."""
+        """Check decorator for update method.
+
+        It checks:
+        - if the plugin is enabled.
+        - if the refresh_timer is finished
+        """
+
         def wrapper(self, *args, **kw):
-            if self.is_enable():
+            if self.is_enabled() and (self.refresh_timer.finished() or self.stats == self.get_init_value):
+                # Run the method
                 ret = fct(self, *args, **kw)
+                # Reset the timer
+                self.refresh_timer.set(self.get_refresh())
+                self.refresh_timer.reset()
             else:
+                # No need to call the method
+                # Return the last result available
                 ret = self.stats
             return ret
+
         return wrapper
 
     def _log_result_decorator(fct):
         """Log (DEBUG) the result of the function fct."""
+
         def wrapper(*args, **kw):
             counter = Counter()
             ret = fct(*args, **kw)
             duration = counter.get()
-            logger.debug("%s %s %s return %s in %s seconds" % (
-                args[0].__class__.__name__,
-                args[0].__class__.__module__[len('glances_'):],
-                fct.__name__, ret,
-                duration))
+            logger.debug(
+                "%s %s %s return %s in %s seconds"
+                % (
+                    args[0].__class__.__name__,
+                    args[0].__class__.__module__[len('glances_') :],
+                    fct.__name__,
+                    ret,
+                    duration,
+                )
+            )
             return ret
+
         return wrapper
 
-    # Mandatory to call the decorator in childs' classes
+    # Mandatory to call the decorator in child classes
     _check_decorator = staticmethod(_check_decorator)
     _log_result_decorator = staticmethod(_log_result_decorator)
