@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2021 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -17,17 +17,19 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-import operator
 import os
 
-from glances.compat import iteritems, itervalues, listitems, iterkeys
-from glances.globals import BSD, LINUX, MACOS, SUNOS, WINDOWS, WSL
+from glances.compat import iterkeys
+from glances.globals import BSD, LINUX, MACOS, WINDOWS
 from glances.timer import Timer, getTimeSinceLastUpdate
 from glances.filter import GlancesFilter
 from glances.logger import logger
 
 import psutil
 
+# This constant defines the list of available processes sort key
+sort_processes_key_list = ['cpu_percent', 'memory_percent', 'username', 'cpu_times', 'io_counters', 'name']
+
 
 class GlancesProcesses(object):
     """Get processed stats using the psutil library."""
@@ -41,7 +43,8 @@ class GlancesProcesses(object):
 
         # The internals caches will be cleaned each 'cache_timeout' seconds
         self.cache_timeout = cache_timeout
-        self.cache_timer = Timer(self.cache_timeout)
+        # First iteration, no cache
+        self.cache_timer = Timer(0)
 
         # Init the io dict
         # key = pid
@@ -57,6 +60,9 @@ class GlancesProcesses(object):
         self.processlist = []
         self.reset_processcount()
 
+        # Cache is a dict with key=pid and value = dict of cached value
+        self.processlist_cache = {}
+
         # Tag to enable/disable the processes stats (to reduce the Glances CPU consumption)
         # Default is to enable the processes stats
         self.disable_tag = False
@@ -104,11 +110,7 @@ class GlancesProcesses(object):
 
     def reset_processcount(self):
         """Reset the global process count"""
-        self.processcount = {'total': 0,
-                             'running': 0,
-                             'sleeping': 0,
-                             'thread': 0,
-                             'pid_max': None}
+        self.processcount = {'total': 0, 'running': 0, 'sleeping': 0, 'thread': 0, 'pid_max': None}
 
     def update_processcount(self, plist):
         """Update the global process count from the current processes list"""
@@ -117,11 +119,9 @@ class GlancesProcesses(object):
         # For each key in the processcount dict
         # count the number of processes with the same status
         for k in iterkeys(self.processcount):
-            self.processcount[k] = len(list(filter(lambda v: v['status'] is k,
-                                                   plist)))
+            self.processcount[k] = len(list(filter(lambda v: v['status'] is k, plist)))
         # Compute thread
-        self.processcount['thread'] = sum(i['num_threads'] for i in plist
-                                          if i['num_threads'] is not None)
+        self.processcount['thread'] = sum(i['num_threads'] for i in plist if i['num_threads'] is not None)
         # Compute total
         self.processcount['total'] = len(plist)
 
@@ -152,7 +152,7 @@ class GlancesProcesses(object):
 
         From `man 5 proc`:
         The default value for this file, 32768, results in the same range of
-        PIDs as on earlier kernels. On 32-bit platfroms, 32768 is the maximum
+        PIDs as on earlier kernels. On 32-bit platforms, 32768 is the maximum
         value for pid_max. On 64-bit systems, pid_max can be set to any value
         up to 2^22 (PID_MAX_LIMIT, approximately 4 million).
 
@@ -261,30 +261,43 @@ class GlancesProcesses(object):
 
         # Grab standard stats
         #####################
-        standard_attrs = ['cmdline', 'cpu_percent', 'cpu_times', 'memory_info',
-                          'memory_percent', 'name', 'nice', 'pid', 'ppid',
-                          'status', 'username', 'status', 'num_threads']
-        if not self.disable_io_counters:
-            standard_attrs += ['io_counters']
-        if not self.disable_gids:
-            standard_attrs += ['gids']
+        sorted_attrs = ['cpu_percent', 'cpu_times', 'memory_percent', 'name', 'status', 'status', 'num_threads']
+        displayed_attr = ['memory_info', 'nice', 'pid', 'ppid']
+        cached_attrs = ['cmdline', 'username']
 
-        # and build the processes stats list (psutil>=5.3.0)
-        self.processlist = [p.info for p in psutil.process_iter(attrs=standard_attrs,
-                                                                ad_value=None)
-                            # OS-related processes filter
-                            if not (BSD and p.info['name'] == 'idle') and
-                            not (WINDOWS and p.info['name'] == 'System Idle Process') and
-                            not (MACOS and p.info['name'] == 'kernel_task') and
-                            # Kernel threads filter
-                            not (self.no_kernel_threads and LINUX and p.info['gids'].real == 0) and
-                            # User filter
-                            not (self._filter.is_filtered(p.info))]
+        # Some stats are optional
+        if not self.disable_io_counters:
+            sorted_attrs.append('io_counters')
+        if not self.disable_gids:
+            displayed_attr.append('gids')
+        # Some stats are not sort key
+        # An optimisation can be done be only grabbed displayed_attr
+        # for displayed processes (but only in standalone mode...)
+        sorted_attrs.extend(displayed_attr)
+        # Some stats are cached (not necessary to be refreshed every time)
+        if self.cache_timer.finished():
+            sorted_attrs += cached_attrs
+            self.cache_timer.set(self.cache_timeout)
+            self.cache_timer.reset()
+            is_cached = False
+        else:
+            is_cached = True
+
+        # Build the processes stats list (it is why we need psutil>=5.3.0)
+        self.processlist = [
+            p.info
+            for p in psutil.process_iter(attrs=sorted_attrs, ad_value=None)
+            # OS-related processes filter
+            if not (BSD and p.info['name'] == 'idle')
+            and not (WINDOWS and p.info['name'] == 'System Idle Process')
+            and not (MACOS and p.info['name'] == 'kernel_task')
+            and
+            # Kernel threads filter
+            not (self.no_kernel_threads and LINUX and p.info['gids'].real == 0)
+        ]
 
         # Sort the processes list by the current sort_key
-        self.processlist = sort_stats(self.processlist,
-                                      sortedby=self.sort_key,
-                                      reverse=True)
+        self.processlist = sort_stats(self.processlist, sorted_by=self.sort_key, reverse=True)
 
         # Update the processcount
         self.update_processcount(self.processlist)
@@ -305,8 +318,7 @@ class GlancesProcesses(object):
                 extended = {}
                 try:
                     top_process = psutil.Process(proc['pid'])
-                    extended_stats = ['cpu_affinity', 'ionice',
-                                      'num_ctx_switches']
+                    extended_stats = ['cpu_affinity', 'ionice', 'num_ctx_switches']
                     if LINUX:
                         # num_fds only avalable on Unix system (see issue #1351)
                         extended_stats += ['num_fds']
@@ -314,14 +326,13 @@ class GlancesProcesses(object):
                         extended_stats += ['num_handles']
 
                     # Get the extended stats
-                    extended = top_process.as_dict(attrs=extended_stats,
-                                                   ad_value=None)
+                    extended = top_process.as_dict(attrs=extended_stats, ad_value=None)
 
                     if LINUX:
                         try:
                             extended['memory_swap'] = sum([v.swap for v in top_process.memory_maps()])
                         except (psutil.NoSuchProcess, KeyError):
-                            # KeyError catch for issue #1551)
+                            # (KeyError catch for issue #1551)
                             pass
                         except (psutil.AccessDenied, NotImplementedError):
                             # NotImplementedError: /proc/${PID}/smaps file doesn't exist
@@ -345,6 +356,9 @@ class GlancesProcesses(object):
             first = False
             # /End of extended stats
 
+            # PID is the key
+            proc['key'] = 'pid'
+
             # Time since last update (for disk_io rate computation)
             proc['time_since_update'] = time_since_update
 
@@ -357,8 +371,7 @@ class GlancesProcesses(object):
             # If io_tag = 0 > Access denied or first time (display "?")
             # If io_tag = 1 > No access denied (display the IO rate)
             if 'io_counters' in proc and proc['io_counters'] is not None:
-                io_new = [proc['io_counters'].read_bytes,
-                          proc['io_counters'].write_bytes]
+                io_new = [proc['io_counters'].read_bytes, proc['io_counters'].write_bytes]
                 # For IO rate computation
                 # Append saved IO r/w bytes
                 try:
@@ -375,18 +388,40 @@ class GlancesProcesses(object):
             # Append the IO tag (for display)
             proc['io_counters'] += [io_tag]
 
+            # Manage cached information
+            if is_cached:
+                # Grab cached values (in case of a new incoming process)
+                if proc['pid'] not in self.processlist_cache:
+                    try:
+                        self.processlist_cache[proc['pid']] = psutil.Process(pid=proc['pid']).as_dict(
+                            attrs=cached_attrs, ad_value=None
+                        )
+                    except psutil.NoSuchProcess:
+                        pass
+                # Add cached value to current stat
+                try:
+                    proc.update(self.processlist_cache[proc['pid']])
+                except KeyError:
+                    pass
+            else:
+                # Save values to cache
+                self.processlist_cache[proc['pid']] = {cached: proc[cached] for cached in cached_attrs}
+
+        # Apply filter
+        self.processlist = [p for p in self.processlist if not (self._filter.is_filtered(p))]
+
         # Compute the maximum value for keys in self._max_values_list: CPU, MEM
-        # Usefull to highlight the processes with maximum values
+        # Useful to highlight the processes with maximum values
         for k in self._max_values_list:
             values_list = [i[k] for i in self.processlist if i[k] is not None]
-            if values_list != []:
+            if values_list:
                 self.set_max_values(k, max(values_list))
 
-    def getcount(self):
+    def get_count(self):
         """Get the number of processes."""
         return self.processcount
 
-    def getlist(self, sortedby=None):
+    def getlist(self, sorted_by=None):
         """Get the processlist."""
         return self.processlist
 
@@ -403,7 +438,7 @@ class GlancesProcesses(object):
         else:
             self.auto_sort = auto
             self._sort_key = key
-    
+
     def kill(self, pid, timeout=3):
         """Kill process with pid"""
         assert pid != os.getpid(), "Glances can kill itself..."
@@ -418,51 +453,46 @@ def weighted(value):
     return -float('inf') if value is None else value
 
 
-def _sort_io_counters(process,
-                      sortedby='io_counters',
-                      sortedby_secondary='memory_percent'):
+def _sort_io_counters(process, sorted_by='io_counters', sorted_by_secondary='memory_percent'):
     """Specific case for io_counters
-    Sum of io_r + io_w"""
-    return process[sortedby][0] - process[sortedby][2] + process[sortedby][1] - process[sortedby][3]
+
+    :return: Sum of io_r + io_w
+    """
+    return process[sorted_by][0] - process[sorted_by][2] + process[sorted_by][1] - process[sorted_by][3]
 
 
-def _sort_cpu_times(process,
-                    sortedby='cpu_times',
-                    sortedby_secondary='memory_percent'):
-    """ Specific case for cpu_times
+def _sort_cpu_times(process, sorted_by='cpu_times', sorted_by_secondary='memory_percent'):
+    """Specific case for cpu_times
+
     Patch for "Sorting by process time works not as expected #1321"
     By default PsUtil only takes user time into account
     see (https://github.com/giampaolo/psutil/issues/1339)
-    The following implementation takes user and system time into account"""
-    return process[sortedby][0] + process[sortedby][1]
+    The following implementation takes user and system time into account
+    """
+    return process[sorted_by][0] + process[sorted_by][1]
 
 
-def _sort_lambda(sortedby='cpu_percent',
-                 sortedby_secondary='memory_percent'):
-    """Return a sort lambda function for the sortedbykey"""
+def _sort_lambda(sorted_by='cpu_percent', sorted_by_secondary='memory_percent'):
+    """Return a sort lambda function for the sorted_by key"""
     ret = None
-    if sortedby == 'io_counters':
+    if sorted_by == 'io_counters':
         ret = _sort_io_counters
-    elif sortedby == 'cpu_times':
+    elif sorted_by == 'cpu_times':
         ret = _sort_cpu_times
     return ret
 
 
-def sort_stats(stats,
-               sortedby='cpu_percent',
-               sortedby_secondary='memory_percent',
-               reverse=True):
-    """Return the stats (dict) sorted by (sortedby).
+def sort_stats(stats, sorted_by='cpu_percent', sorted_by_secondary='memory_percent', reverse=True):
+    """Return the stats (dict) sorted by (sorted_by).
 
     Reverse the sort if reverse is True.
     """
-    if sortedby is None and sortedby_secondary is None:
+    if sorted_by is None and sorted_by_secondary is None:
         # No need to sort...
         return stats
 
     # Check if a specific sort should be done
-    sort_lambda = _sort_lambda(sortedby=sortedby,
-                               sortedby_secondary=sortedby_secondary)
+    sort_lambda = _sort_lambda(sorted_by=sorted_by, sorted_by_secondary=sorted_by_secondary)
 
     if sort_lambda is not None:
         # Specific sort
@@ -470,19 +500,20 @@ def sort_stats(stats,
             stats.sort(key=sort_lambda, reverse=reverse)
         except Exception:
             # If an error is detected, fallback to cpu_percent
-            stats.sort(key=lambda process: (weighted(process['cpu_percent']),
-                                            weighted(process[sortedby_secondary])),
-                       reverse=reverse)
+            stats.sort(
+                key=lambda process: (weighted(process['cpu_percent']), weighted(process[sorted_by_secondary])),
+                reverse=reverse,
+            )
     else:
         # Standard sort
         try:
-            stats.sort(key=lambda process: (weighted(process[sortedby]),
-                                            weighted(process[sortedby_secondary])),
-                       reverse=reverse)
+            stats.sort(
+                key=lambda process: (weighted(process[sorted_by]), weighted(process[sorted_by_secondary])),
+                reverse=reverse,
+            )
         except (KeyError, TypeError):
             # Fallback to name
-            stats.sort(key=lambda process: process['name'] if process['name'] is not None else '~',
-                       reverse=False)
+            stats.sort(key=lambda process: process['name'] if process['name'] is not None else '~', reverse=False)
 
     return stats
 
